@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2008- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -144,8 +144,15 @@ struct hash_table *chirp_audit(const char *path)
 
 void chirp_audit_delete(struct hash_table *table)
 {
-	hash_table_clear(table, free);
+	char *key;
+	struct chirp_audit *entry;
+
+	hash_table_firstkey(table);
+	while(hash_table_nextkey(table, &key, (void *) &entry)) {
+		free(hash_table_remove(table, key));
+	}
+
 	hash_table_delete(table);
 }
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
