@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2008- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -765,6 +765,9 @@ struct chirp_filesystem chirp_fs_hdfs = {
 	cfs_stub_lremovexattr,
 
 	chirp_fs_hdfs_do_acl_check,
+
+	cfs_stub_job_dbinit,
+	cfs_stub_job_schedule,
 };
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
