@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2008- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -653,7 +653,7 @@ INT64_T chirp_multi_statfs(const char *volume, const char *path, struct chirp_st
 	buf->f_bavail = bytes_avail / block_size;
 	buf->f_bfree = bytes_free / block_size;
 	buf->f_files = files_total;
-	buf->f_ffree = files_free;
+	buf->f_ffree = files_total;
 
 	return 0;
 }
@@ -728,7 +728,7 @@ INT64_T chirp_multi_utime(const char *volume, const char *path, time_t actime, t
 	}
 }
 
-INT64_T chirp_multi_md5(const char *volume, const char *path, unsigned char digest[CHIRP_DIGEST_MAX], time_t stoptime)
+INT64_T chirp_multi_md5(const char *volume, const char *path, unsigned char digest[16], time_t stoptime)
 {
 	struct file_info info;
 	if(chirp_multi_lookup(volume, path, &info, stoptime)) {
@@ -738,4 +738,4 @@ INT64_T chirp_multi_md5(const char *volume, const char *path, unsigned char dige
 	}
 }
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
