@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2005- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -696,7 +696,7 @@ INT64_T chirp_reli_hash( const char *host, const char *path, const char *algorit
 	RETRY_ATOMIC( result = chirp_client_hash(client,path,algorithm,digest,stoptime); )
 }
 
-INT64_T chirp_reli_md5( const char *host, const char *path, unsigned char digest[CHIRP_DIGEST_MAX], time_t stoptime )
+INT64_T chirp_reli_md5( const char *host, const char *path, unsigned char digest[16], time_t stoptime )
 {
 	RETRY_ATOMIC( result = chirp_client_md5(client,path,digest,stoptime); )
 }
@@ -781,19 +781,19 @@ INT64_T chirp_reli_job_create (const char *host, const char *json, chirp_jobid_t
 	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_create(client,json,id,stoptime); )
 }
 
-INT64_T chirp_reli_job_commit (const char *host, chirp_jobid_t id, time_t stoptime)
+INT64_T chirp_reli_job_commit (const char *host, const char *json, time_t stoptime)
 {
-	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_commit(client,id,stoptime); )
+	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_commit(client,json,stoptime); )
 }
 
-INT64_T chirp_reli_job_kill (const char *host, chirp_jobid_t id, time_t stoptime)
+INT64_T chirp_reli_job_kill (const char *host, const char *json, time_t stoptime)
 {
-	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_kill(client,id,stoptime); )
+	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_kill(client,json,stoptime); )
 }
 
-INT64_T chirp_reli_job_status (const char *host, chirp_jobid_t id, char **status, time_t stoptime)
+INT64_T chirp_reli_job_status (const char *host, const char *json, char **status, time_t stoptime)
 {
-	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_status(client,id,status,stoptime); )
+	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_status(client,json,status,stoptime); )
 }
 
 INT64_T chirp_reli_job_wait (const char *host, chirp_jobid_t id, INT64_T timeout, char **status, time_t stoptime)
@@ -801,9 +801,9 @@ INT64_T chirp_reli_job_wait (const char *host, chirp_jobid_t id, INT64_T timeout
 	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_wait(client,id,timeout,status,stoptime); )
 }
 
-INT64_T chirp_reli_job_reap (const char *host, chirp_jobid_t id, time_t stoptime)
+INT64_T chirp_reli_job_reap (const char *host, const char *json, time_t stoptime)
 {
-	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_reap(client,id,stoptime); )
+	RETRY_ATOMIC_NOEAGAIN( result = chirp_client_job_reap(client,json,stoptime); )
 }
 
 INT64_T chirp_reli_remote_debug( const char *host, const char *flag, time_t stoptime )
@@ -1031,4 +1031,4 @@ void chirp_reli_cleanup_before_fork()
 	}
 }
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
