@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2005- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -87,6 +87,7 @@ INT64_T chirp_reli_pread(struct chirp_file *file, void *buffer, INT64_T length,
 @param offset Beginning offset in file.
 @param stoptime The absolute time at which to abort.
 @return On success, returns the number of bytes actually written, which may be less than requested.  On failure, <0 and sets errno.
+@param stoptime The absolute time at which to abort.
 @see chirp_reli_open, chirp_reli_swrite
 */
 
@@ -126,6 +127,7 @@ up to a maximum of <tt>length</tt> bytes read.
 @param offset Beginning offset in file.
 @param stoptime The absolute time at which to abort.
 @return On success, returns the number of bytes actually read, which may be less than requested.  On failure, <0 and sets errno.
+@param stoptime The absolute time at which to abort.
 @see chirp_reli_open, chirp_reli_pread, chirp_reli_pwrite, chirp_reli_sread, chirp_reli_swrite
 */
 
@@ -141,6 +143,7 @@ up to a maximum of <tt>length</tt> bytes written.
 @param offset Beginning offset in file.
 @param stoptime The absolute time at which to abort.
 @return On success, returns the number of bytes actually written, which may be less than requested.  On failure, <0 and sets errno.
+@param stoptime The absolute time at which to abort.
 @see chirp_reli_open, chirp_reli_pread, chirp_reli_pwrite, chirp_reli_sread, chirp_reli_swrite
 */
 
@@ -337,69 +340,13 @@ Note that this function has no timeoutbecause it operates solely on memory struc
 
 void chirp_reli_closedir(struct chirp_dir *dir);
 
-/** Create a new blank access control ticket.
-@param host The name and port of the Chirp server to access.
-@param name An empty array that will be filled with a unique ticket filename.
-@param bits The cryptographic length of the ticket, in bits. (typically 1024)
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
+/* FIXME document */
 INT64_T chirp_reli_ticket_create(const char *host, char name[CHIRP_PATH_MAX], unsigned bits, time_t stoptime);
-
-/** Register an access control ticket with a file serer.
-@param host The name and port of the Chirp server to access.
-@param name The name of an existing ticket.
-@param subject The subject to be granted access with this ticket, which should be "self" for normal users.
-@param duration The lifetime of this ticket, in seconds.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
 INT64_T chirp_reli_ticket_register(const char *host, const char *name, const char *subject, time_t duration, time_t stoptime);
-
-/** Modify an access control ticket to grant futher access.
-@param host The name and port of the Chirp server to access.
-@param name The name of an existing ticket.
-@param path The filesystem path that will be added to the ticket.
-@param aclmask The access rights that will be added to the ticket, any of "rwldax".
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
-INT64_T chirp_reli_ticket_modify(const char *host, const char *name, const char *path, const char *aclmask, time_t stoptime);
-
-/** Get the details of a registered ticket.
-@param host The name and port of the Chirp server to access.
-@param name The name of an existing ticket.
-@param subject A pointer to a string that will be allocated with the name of the ticket owner.
-@param ticket A pointer to a string that will be allocated with the name of the ticket.  (XXX)
-@param duration A pointer to an integer that will be filled with the duration of the ticket.
-@param rights A pointer to a list of strings that will be filled with ticket rights.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
-INT64_T chirp_reli_ticket_get(const char *host, const char *name, char **subject, char **ticket, time_t * duration, char ***rights, time_t stoptime);
-
-/** List registered tikets on a server.
-@param host The name and port of the Chirp server to access.
-@param subject The user whose tickets to list, typically "self" for a normal user.
-@param list A pointer to an (unallocated) list of strings which will be filled in with registered tickets.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
-INT64_T chirp_reli_ticket_list(const char *host, const char *subject, char ***list, time_t stoptime);
-
-/** Delete an access control ticket.
-@param host The name and port of the Chirp server to access.
-@param name The name of an existing ticket file on the local filesystem.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
 INT64_T chirp_reli_ticket_delete(const char *host, const char *name, time_t stoptime);
+INT64_T chirp_reli_ticket_list(const char *host, const char *subject, char ***list, time_t stoptime);
+INT64_T chirp_reli_ticket_get(const char *host, const char *name, char **subject, char **ticket, time_t * duration, char ***rights, time_t stoptime);
+INT64_T chirp_reli_ticket_modify(const char *host, const char *name, const char *path, const char *aclmask, time_t stoptime);
 
 /** Get an access control list.
 @param host The name and port of the Chirp server to access.
@@ -681,17 +628,17 @@ INT64_T chirp_reli_hash(const char *host, const char *path, const char *algorith
 /** Checksum a remote file. (DEPRECATED: use @ref chirp_reli_hash)
 This MD5 checksum is performed remotely by the file server, so it is much more
 efficient than computing one by invoking a local command.  Note that the data
-is returned in <b>binary</b> digest form.  Use @ref md5_to_string to convert the
+is returned in <b>binary</b> digest form.  Use @ref md5_string to convert the
 digest into a human readable form.
 @param host The name and port of the Chirp server to access.
 @param path The pathname of the file to access.
 @param digest The buffer to place the binary checksum digest.
 @param stoptime The absolute time at which to abort.
 @return On success, returns length of digest.  On failure, returns less than zero and sets errno.
-@see md5_to_string
+@see md5_string
 */
 
-INT64_T chirp_reli_md5(const char *host, const char *path, unsigned char digest[CHIRP_DIGEST_MAX], time_t stoptime);
+INT64_T chirp_reli_md5(const char *host, const char *path, unsigned char digest[16], time_t stoptime);
 
 /** Set replication factor.
 Sets the number of replicas desired for the indicated file or for all newly created files.
@@ -719,11 +666,11 @@ INT64_T chirp_reli_fremovexattr(struct chirp_file *file, const char *name, time_
 INT64_T chirp_reli_lremovexattr(const char *host, const char *path, const char *name, time_t stoptime);
 
 INT64_T chirp_reli_job_create (const char *host, const char *json, chirp_jobid_t *id, time_t stoptime);
-INT64_T chirp_reli_job_commit (const char *host, chirp_jobid_t id, time_t stoptime);
-INT64_T chirp_reli_job_kill (const char *host, chirp_jobid_t id, time_t stoptime);
-INT64_T chirp_reli_job_status (const char *host, chirp_jobid_t id, char **status, time_t stoptime);
+INT64_T chirp_reli_job_commit (const char *host, const char *json, time_t stoptime);
+INT64_T chirp_reli_job_kill (const char *host, const char *json, time_t stoptime);
+INT64_T chirp_reli_job_status (const char *host, const char *json, char **status, time_t stoptime);
 INT64_T chirp_reli_job_wait (const char *host, chirp_jobid_t id, INT64_T timeout, char **status, time_t stoptime);
-INT64_T chirp_reli_job_reap (const char *host, chirp_jobid_t id, time_t stoptime);
+INT64_T chirp_reli_job_reap (const char *host, const char *json, time_t stoptime);
 
 /** Set the debug options on the remote server.
 @param host The name and port of the Chirp server to access.
@@ -848,4 +795,4 @@ void chirp_reli_disconnect( const char *host );
 
 #endif
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
