@@ -164,7 +164,7 @@ int main(int argc, char **argv) {
 	return 0;
 }
 EOF
-	if ${CC:-gcc} ${CFLAGS} .configure.tmp.c -c -o .configure.tmp.o ${compiler_options} > .configure.tmp.out 2>&1; then
+	if ${CC:-gcc} .configure.tmp.c -c -o .configure.tmp.o ${compiler_options} > .configure.tmp.out 2>&1; then
 		echo yes
 		rm -f .configure.tmp.c .configure.tmp.out
 		return 0
@@ -418,7 +418,7 @@ cat > .configure.tmp.c << EOF
 #include <stdlib.h>
 #include <${header}>
 EOF
-	if ${CC:-gcc} ${CFLAGS} .configure.tmp.c -c -o .configure.tmp.o > .configure.tmp.out 2>&1; then
+	if ${CC:-gcc} .configure.tmp.c -c -o .configure.tmp.o > .configure.tmp.out 2>&1; then
 		echo yes
 		rm -f .configure.tmp.c .configure.tmp.out
 		ccflags_append_define "$@"
@@ -718,7 +718,7 @@ report_detection()
 		echo "compiling with ${package} support"
 	elif [ "${required}" = no ]
 	then
-		echo "${package} support explicitly disabled"
+		echo "${package} support explicitely disabled"
 	elif [ "${required}" = yes ]
 	then
 		echo "*** Sorry, I couldn't find ${package} in ${path_tried}"
