@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2005- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -18,7 +18,7 @@ See the file COPYING for details.
 #include "jx_parse.h"
 #include "jx_print.h"
 #include "jx_table.h"
-#include "catalog_export.h"
+#include "jx_export.h"
 #include "jx_eval.h"
 #include "stringtools.h"
 #include "domain_name_cache.h"
@@ -76,19 +76,7 @@ static time_t clean_interval = 60;
 /* The port upon which to listen. */
 static int port = CATALOG_PORT_DEFAULT;
 
-/* The SSL port upon which to listen. */
-static int ssl_port = 0;
-
-/* Filename containing the SSL certificate. */
-static const char *ssl_cert_filename = 0;
-
-/* Filename containing the SSL private key. */
-static const char *ssl_key_filename = 0;
-
-/* The file for writing out the SSL port number. */
-const char *ssl_port_file = 0;
-
-/* The file for writing out the query port number. */
+/* The file for writing out the port number. */
 const char *port_file = 0;
 
 /* The preferred hostname set on the command line. */
@@ -115,9 +103,6 @@ static int child_procs_count = 0;
 /* Maximum time to allow a child process to run. */
 static int child_procs_timeout = 60;
 
-/* Maximum time to allow a streaming child process to run. */
-static int streaming_procs_timeout = 3600;
-
 /* The maximum size of a server that will actually be believed. */
 static INT64_T max_server_size = 0;
 
@@ -139,21 +124,6 @@ static char data[1024*1024];
 struct datagram *update_dgram = 0;
 struct link *update_port = 0;
 
-/*
-Shutdown *without* performing cleanup, so as to avoid (surprisingly common)
-deadlocks when a SIGALRM is received while in the middle of SSL negotiation.
-*/
-
-void shutdown_fast(int sig)
-{
-	_exit(0);
-}
-
-/*
-Shutdown normally, calling destructors, atexit, and so forth when a manual
-shutdown signal is received.
-*/
-
 void shutdown_clean(int sig)
 {
 	exit(0);
@@ -238,11 +208,7 @@ static void update_all_catalogs()
 	char *text = jx_print_string(j);
 	jx_delete(j);
 
-	const char *host;
-	LIST_ITERATE(outgoing_host_list,host) {
-		catalog_query_send_update(host,text,CATALOG_UPDATE_BACKGROUND);
-	}
-
+	list_iterate(outgoing_host_list, (list_op_t) catalog_query_send_update, text);
 	free(text);
 }
 
@@ -417,11 +383,7 @@ void handle_tcp_update( struct link *update_port )
 
 	if(length>0) {
 		data[length] = 0;
-		if(length>4 && !strncmp(data,"GET ",4)) {
-			// Random web server is connecting, reject it.
-		} else {
-			handle_update(addr,port,data,length,"tcp");
-		}
+		handle_update(addr,port,data,length,"tcp");
 	}
 
 	link_close(l);
@@ -432,6 +394,9 @@ static struct jx_table html_headers[] = {
 	{"name", "NAME", JX_TABLE_MODE_PLAIN, JX_TABLE_ALIGN_LEFT, 0},
 	{"port", "PORT", JX_TABLE_MODE_PLAIN, JX_TABLE_ALIGN_LEFT, 0},
 	{"owner", "OWNER", JX_TABLE_MODE_PLAIN, JX_TABLE_ALIGN_LEFT, 0},
+	{"total", "TOTAL", JX_TABLE_MODE_METRIC, JX_TABLE_ALIGN_RIGHT, 0},
+	{"avail", "AVAIL", JX_TABLE_MODE_METRIC, JX_TABLE_ALIGN_RIGHT, 0},
+	{"load5", "LOAD5", JX_TABLE_MODE_PLAIN, JX_TABLE_ALIGN_RIGHT, 0},
 	{"version", "VERSION", JX_TABLE_MODE_PLAIN, JX_TABLE_ALIGN_LEFT, 0},
 	{0,0,0,0,0}
 };
@@ -444,33 +409,22 @@ int jx_eval_is_true( struct jx *expr, struct jx *context )
 	return result;
 }
 
-void send_http_response( struct link *l, int code, const char *message, const char *content_type, time_t stoptime )
+void send_http_response( FILE *stream, int code, const char *message, const char *content_type )
 {
 	time_t current = time(0);
-	link_printf(l,stoptime, "HTTP/1.1 %d %s\n",code,message);
-	link_printf(l,stoptime, "Date: %s", ctime(&current));
-	link_printf(l,stoptime, "Server: catalog_server\n");
-	link_printf(l,stoptime, "Connection: close\n");
-	link_printf(l,stoptime, "Access-Control-Allow-Origin: *\n");
-	link_printf(l,stoptime, "Content-type: %s; charset=utf-8\n\n",content_type);
-	link_flush_output(l);
+	fprintf(stream, "HTTP/1.1 %d %s\n",code,message);
+	fprintf(stream, "Date: %s", ctime(&current));
+	fprintf(stream, "Server: catalog_server\n");
+	fprintf(stream, "Connection: close\n");
+	fprintf(stream, "Access-Control-Allow-Origin: *\n");
+	fprintf(stream, "Content-type: %s\n\n",content_type);
 }
 
-void send_html_header( struct link *l, time_t stoptime )
-{
-	link_printf(l,stoptime, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">\n");
-	link_printf(l,stoptime, "<head>\n");
-	link_printf(l,stoptime, "<title>%s catalog server</title>\n", preferred_hostname);
-	link_printf(l,stoptime, "</head>\n");
-}
-
-/* Handle an incoming HTTP query (or update) on an authenticated link. */
-
-static void handle_query( struct link *ql, time_t st )
+static void handle_query(struct link *query_link)
 {
+	FILE *stream;
 	char line[LINE_MAX];
 	char url[LINE_MAX];
-	char full_path[LINE_MAX];
 	char path[LINE_MAX];
 	char action[LINE_MAX];
 	char version[LINE_MAX];
@@ -480,106 +434,49 @@ static void handle_query( struct link *ql, time_t st )
 	char strexpr[LINE_MAX];
 	int port;
 	long time_start, time_stop;
-	long timestamp = 0;
 
 	char *hkey;
 	struct jx *j;
 	int i, n;
 
-	link_address_remote(ql, addr, &port);
-	debug(D_DEBUG, "%s query from %s:%d", link_using_ssl(ql) ? "https" : "http", addr, port);
+	link_address_remote(query_link, addr, &port);
+	debug(D_DEBUG, "www query from %s:%d", addr, port);
 
-	/* Read the HTTP action, url, and version */
-
-	if(link_readline(ql, line, LINE_MAX, time(0) + HANDLE_QUERY_TIMEOUT)) {
+	if(link_readline(query_link, line, LINE_MAX, time(0) + HANDLE_QUERY_TIMEOUT)) {
 		string_chomp(line);
 		if(sscanf(line, "%s %s %s", action, url, version) != 3) {
 			return;
 		}
 
-		/* Now consume the rest of the header name-value pairs, which we don't care about. */
-
+		// Consume the rest of the query
 		while(1) {
-			/* If we read to end-of-stream on the request, that's ok. */
-			if(!link_readline(ql, line, LINE_MAX, time(0) + HANDLE_QUERY_TIMEOUT)) {
-				break;
+			if(!link_readline(query_link, line, LINE_MAX, time(0) + HANDLE_QUERY_TIMEOUT)) {
+				return;
 			}
 
-			/* If we get a blank line separator, proceed to respond. */
 			if(line[0] == 0) {
 				break;
 			}
 		}
 	} else {
-		/* Read of initial HTTP line failed, so give up. */
 		return;
 	}
 
-	/* Extract the path from the full URL (or if a simple path, just use it. */
+	// Output response
+	stream = fdopen(link_fd(query_link), "w");
+	if(!stream) {
+		return;
+	}
+	link_nonblocking(query_link, 0);
 
-	if(sscanf(url, "http://%[^/]%s", hostport, full_path) == 2) {
+	if(sscanf(url, "http://%[^/]%s", hostport, path) == 2) {
 		// continue on
 	} else {
-		strcpy(full_path, url);
+		strcpy(path, url);
 	}
 
-	/* If the query is asking for a raw update stream, process that now wihout loading data. */
-	if(3==sscanf(full_path, "/updates/%ld/%ld/%[^/]",&time_start,&time_stop,strexpr)) {
-		struct buffer buf;
-		buffer_init(&buf);
+	/* load the hash table entries into one big array */
 
-		/* The filter text is b64 encoded in strexpr */
-		if(b64_decode(strexpr,&buf)==0) {
-
-			/* And that filter text must be a constant JX expression */
-			struct jx *expr = jx_parse_string(buffer_tostring(&buf));
-			if(expr) {
-				if(link_using_ssl(ql)) {
-					send_http_response(ql,501,"Server Error","text/plain",st);
-					link_printf(ql,st,"Sorry, unable to serve queries over HTTPS.");
-				} else {
-					send_http_response(ql,200,"OK","text/plain",st);
-
-					/* These can be long running, so set a longer timeout. */
-					alarm(streaming_procs_timeout);
-
-					struct deltadb_query *query = deltadb_query_create();
-
-					/* The query will only produce records matching the filter. */
-					deltadb_query_set_filter(query,expr);
-					// Note this leaks a stdio stream, but it will be shortly recovered on process exit.
-					deltadb_query_set_output(query,fdopen(link_fd(ql),"w"));
-					deltadb_query_set_display(query,DELTADB_DISPLAY_STREAM);
-					deltadb_query_execute_dir(query,history_dir,time_start,time_stop);
-					deltadb_query_delete(query);
-					jx_delete(expr);
-				}
-			} else {
-				send_http_response(ql,400,"Bad Request","text/plain",st);
-				link_printf(ql,st,"Invalid query text.\n");
-			}
-		} else {
-			send_http_response(ql,400,"Bad Request","text/plain",st);
-			link_printf(ql,st,"Invalid base-64 encoding.\n");
-		}
-		buffer_free(&buf);
-		return;
-	}
-
-	/* A /history prefix indicates a single snapshot from the given time. */
-	int matches = sscanf(full_path, "/history/%ld%s", &timestamp, path);
-	if (matches == 2) {
-		/* Replace the current table with a snapshot table. */
-		table = deltadb_create_snapshot(history_dir, timestamp);
-	} else if (matches == 1) {
-		strncpy(path, "/", sizeof(path));
-		/* Replace the current table with a snapshot table. */
-		table = deltadb_create_snapshot(history_dir, timestamp);
-	} else {
-		strcpy(path, full_path);
-	}
-
-	/* Now transform the hashtable into one big array for sorting. */
 	n = 0;
 	deltadb_firstkey(table);
 	while(deltadb_nextkey(table, &hkey, &j)) {
@@ -587,23 +484,22 @@ static void handle_query( struct link *ql, time_t st )
 		n++;
 	}
 
-	/* Sort the array by name before displaying. */
+	/* sort the array by name before displaying */
+
 	qsort(array, n, sizeof(struct jx *), compare_jx);
 
-	/* Now consider the various forms of a basic snapshot query. */
-
 	if(!strcmp(path, "/query.text")) {
-		send_http_response(ql,200,"OK","text/plain",st);
+		send_http_response(stream,200,"OK","text/plain");
 		for(i = 0; i < n; i++)
-			catalog_export_nvpair(array[i], ql,st);
+			jx_export_nvpair(array[i], stream);
 	} else if(!strcmp(path, "/query.json")) {
-		send_http_response(ql,200,"OK","text/plain",st);
-		link_printf(ql,st,"[\n");
+		send_http_response(stream,200,"OK","text/plain");
+		fprintf(stream,"[\n");
 		for(i = 0; i < n; i++) {
-			jx_print_link(array[i],ql,st);
-			if(i<(n-1)) link_printf(ql,st,",\n");
+			jx_print_stream(array[i],stream);
+			if(i<(n-1)) fprintf(stream,",\n");
 		}
-		link_printf(ql,st,"\n]\n");
+		fprintf(stream,"\n]\n");
 	} else if(1==sscanf(path, "/query/%[^/]",strexpr)) {
 
 		struct buffer buf;
@@ -611,88 +507,111 @@ static void handle_query( struct link *ql, time_t st )
 		if(b64_decode(strexpr,&buf)==0) {
 			struct jx *expr = jx_parse_string(buffer_tostring(&buf));
 			if(expr) {
-				send_http_response(ql,200,"OK","text/plain",st);
-				link_printf(ql,st,"[\n");
+				send_http_response(stream,200,"OK","text/plain");
+				fprintf(stream,"[\n");
 
-				int count = 0;
+				int first = 1;
 				for(i = 0; i < n; i++) {
 					if(jx_eval_is_true(expr,array[i])) {
-						if(count>0) link_printf(ql,st,",\n");
-						jx_print_link(array[i],ql,st);
-						count++;
+						if(!first) fprintf(stream,",\n");
+						jx_print_stream(array[i],stream);
+						first = 0;
 					}
 				}
-				link_printf(ql,st,"\n]\n");
+				fprintf(stream,"\n]\n");
 				jx_delete(expr);
-				debug(D_DEBUG,"query '%s' matched %d records",buffer_tostring(&buf),count);
 			} else {
-				send_http_response(ql,400,"Bad Request","text/plain",st);
-				link_printf(ql,st,"Invalid query text.\n");
-				debug(D_DEBUG,"query '%s' failed jx parse",buffer_tostring(&buf));
+				send_http_response(stream,400,"Bad Request","text/plain");
+				fprintf(stream,"Invalid query text.\n");
 			}
 		} else {
-			send_http_response(ql,400,"Bad Request","text/plain",st);
-			link_printf(ql,st,"Invalid base-64 encoding.\n");
-			debug(D_DEBUG,"query '%s' failed base-64 decode",strexpr);
+			send_http_response(stream,400,"Bad Request","text/plain");
+			fprintf(stream,"Invalid base-64 encoding.\n");
 		}
 		buffer_free(&buf);
 
-	} else if(!strcmp(path, "/query.newclassads")) {
-		send_http_response(ql,200,"OK","text/plain",st);
+
+	} else if(3==sscanf(path, "/history/%ld/%ld/%[^/]",&time_start,&time_stop,strexpr)) {
+
+		struct buffer buf;
+		buffer_init(&buf);
+		if(b64_decode(strexpr,&buf)==0) {
+			struct jx *expr = jx_parse_string(buffer_tostring(&buf));
+			if(expr) {
+				send_http_response(stream,200,"OK","text/plain");
+				struct deltadb_query *query = deltadb_query_create();
+				deltadb_query_set_filter(query,expr);
+				deltadb_query_set_output(query,stream);
+				deltadb_query_set_display(query,DELTADB_DISPLAY_STREAM);
+				deltadb_query_execute_dir(query,history_dir,time_start,time_stop);
+				deltadb_query_delete(query);
+				jx_delete(expr);
+			} else {
+				send_http_response(stream,400,"Bad Request","text/plain");
+				fprintf(stream,"Invalid query text.\n");
+			}
+		} else {
+			send_http_response(stream,400,"Bad Request","text/plain");
+			fprintf(stream,"Invalid base-64 encoding.\n");
+		}
+		buffer_free(&buf);
+
+
+	} else if(!strcmp(path, "/query.oldclassads")) {
+		send_http_response(stream,200,"OK","text/plain");
 		for(i = 0; i < n; i++)
-			catalog_export_new_classads(array[i], ql,st);
+			jx_export_old_classads(array[i], stream);
+	} else if(!strcmp(path, "/query.newclassads")) {
+		send_http_response(stream,200,"OK","text/plain");
+		for(i = 0; i < n; i++)
+			jx_export_new_classads(array[i], stream);
+	} else if(!strcmp(path, "/query.xml")) {
+		send_http_response(stream,200,"OK","text/xml");
+		fprintf(stream, "<?xml version=\"1.0\" standalone=\"yes\"?>\n");
+		fprintf(stream, "<catalog>\n");
+		for(i = 0; i < n; i++)
+			jx_export_xml(array[i], stream);
+		fprintf(stream, "</catalog>\n");
 	} else if(sscanf(path, "/detail/%s", key) == 1) {
 		struct jx *j;
-		send_http_response(ql,200,"OK","text/html",st);
+		send_http_response(stream,200,"OK","text/html");
 		j = deltadb_lookup(table, key);
 		if(j) {
 			const char *name = jx_lookup_string(j, "name");
 			if(!name)
 				name = "unknown";
-			send_html_header(ql,st);
-			link_printf(ql,st, "<center>\n");
-			link_printf(ql,st, "<h1>%s catalog server</h1>\n", preferred_hostname);
-			link_printf(ql,st, "<h2>%s</h2>\n", name);
-			if (timestamp) {
-				link_printf(ql,st, "<p><a href=/history/%ld/>return to catalog view</a><p>\n", timestamp);
-			} else {
-				link_printf(ql,st, "<p><a href=/>return to catalog view</a><p>\n");
-			}
-			catalog_export_html_solo(j, ql,st);
-			link_printf(ql,st, "</center>\n");
+			fprintf(stream, "<title>%s catalog server: %s</title>\n", preferred_hostname, name);
+			fprintf(stream, "<center>\n");
+			fprintf(stream, "<h1>%s catalog server</h1>\n", preferred_hostname);
+			fprintf(stream, "<h2>%s</h2>\n", name);
+			fprintf(stream, "<p><a href=/>return to catalog view</a><p>\n");
+			jx_export_html_solo(j, stream);
+			fprintf(stream, "</center>\n");
 		} else {
-			send_html_header(ql,st);
-			link_printf(ql,st, "<center>\n");
-			link_printf(ql,st, "<h1>%s catalog server</h1>\n", preferred_hostname);
-			link_printf(ql,st, "<h2>Unknown Item!</h2>\n");
-			link_printf(ql,st, "</center>\n");
+			fprintf(stream, "<title>%s catalog server</title>\n", preferred_hostname);
+			fprintf(stream, "<center>\n");
+			fprintf(stream, "<h1>%s catalog server</h1>\n", preferred_hostname);
+			fprintf(stream, "<h2>Unknown Item!</h2>\n");
+			fprintf(stream, "</center>\n");
 		}
-	} else if(!strcmp(path,"/") || !strcmp(path,"/query.html") ) {
+	} else if(!strcmp(path,"/")) {
 		char avail_line[LINE_MAX];
 		char total_line[LINE_MAX];
 		INT64_T sum_total = 0;
 		INT64_T sum_avail = 0;
 		INT64_T sum_devices = 0;
 
-		send_http_response(ql,200,"OK","text/html",st);
-		send_html_header(ql,st);
-		link_printf(ql,st, "<center>\n");
-		link_printf(ql,st, "<h1>%s catalog server</h1>\n", preferred_hostname);
-		if (timestamp) {
-			catalog_export_html_datetime_picker(ql, st, timestamp);
-			link_printf(ql,st, "<h3>Historical Snapshot as of %s</h3>", ctime(&timestamp));
-			link_printf(ql,st, "<a href=/history/%ld/query.text>text</a> - ", timestamp);
-			link_printf(ql,st, "<a href=/history/%ld/query.html>html</a> - ", timestamp);
-			link_printf(ql,st, "<a href=/history/%ld/query.json>json</a> - ", timestamp);
-			link_printf(ql,st, "<a href=/history/%ld/query.newclassads>classads</a>", timestamp);
-		} else {
-			catalog_export_html_datetime_picker(ql, st, time(0));
-			link_printf(ql,st, "<a href=/query.text>text</a> - ");
-			link_printf(ql,st, "<a href=/query.html>html</a> - ");
-			link_printf(ql,st, "<a href=/query.json>json</a> - ");
-			link_printf(ql,st, "<a href=/query.newclassads>classads</a>");
-		}
-		link_printf(ql,st, "<p>\n");
+		send_http_response(stream,200,"OK","text/html");
+		fprintf(stream, "<title>%s catalog server</title>\n", preferred_hostname);
+		fprintf(stream, "<center>\n");
+		fprintf(stream, "<h1>%s catalog server</h1>\n", preferred_hostname);
+		fprintf(stream, "<a href=/query.text>text</a> - ");
+		fprintf(stream, "<a href=/query.html>html</a> - ");
+		fprintf(stream, "<a href=/query.xml>xml</a> - ");
+		fprintf(stream, "<a href=/query.json>json</a> - ");
+		fprintf(stream, "<a href=/query.oldclassads>oldclassads</a> - ");
+		fprintf(stream, "<a href=/query.newclassads>newclassads</a>");
+		fprintf(stream, "<p>\n");
 
 		for(i = 0; i < n; i++) {
 			j = array[i];
@@ -703,65 +622,24 @@ static void handle_query( struct link *ql, time_t st )
 
 		string_metric(sum_avail, -1, avail_line);
 		string_metric(sum_total, -1, total_line);
-		link_printf(ql,st, "<b>%sB available out of %sB on %d devices</b><p>\n", avail_line, total_line, (int) sum_devices);
+		fprintf(stream, "<b>%sB available out of %sB on %d devices</b><p>\n", avail_line, total_line, (int) sum_devices);
 
-		catalog_export_html_header(ql, html_headers, st);
+		jx_export_html_header(stream, html_headers);
 		for(i = 0; i < n; i++) {
 			j = array[i];
 			make_hash_key(j, key);
-			if (timestamp) {
-				string_nformat(url, sizeof(url), "/history/%ld/detail/%s", timestamp, key);
-			} else {
-				string_nformat(url, sizeof(url), "/detail/%s", key);
-			}
-			catalog_export_html_with_link(j, ql, html_headers, "name", url, st);
+			string_nformat(url, sizeof(url), "/detail/%s", key);
+			jx_export_html_with_link(j, stream, html_headers, "name", url);
 		}
-		catalog_export_html_footer(ql, html_headers, st);
-		link_printf(ql,st, "</center>\n");
+		jx_export_html_footer(stream, html_headers);
+		fprintf(stream, "</center>\n");
 	} else {
-		send_http_response(ql,404,"Not Found","text/html",st);
-		link_printf(ql,st,"<p>Error 404: Invalid URL</p>");
-		link_printf(ql,st,"<pre>%s</pre>",path);
-		link_printf(ql,st,"<p><a href=/>Return to Index</a></p>");
+		send_http_response(stream,404,"Not Found","text/html");
+		fprintf(stream,"<p>Error 404: Invalid URL</p>");
+		fprintf(stream,"<pre>%s</pre>",url);
+		fprintf(stream,"<p><a href=/>Return to Index</a></p>");
 	}
-}
-
-/* Handle an incoming TCP connection by forking, authenticating, and then processing the query. */
-
-void handle_tcp_query( struct link *port, int using_ssl )
-{
-	char raddr[LINK_ADDRESS_MAX];
-	int rport;
-	link_address_remote(port, raddr, &rport);
-
-	link_buffer_output(port,4096);
-
-	if(fork_mode) {
-		pid_t pid = fork();
-		if(pid == 0) {
-			change_process_title("catalog_server [%s]", raddr);
-			alarm(child_procs_timeout);
-			if(using_ssl) {
-				if(!link_ssl_wrap_accept(port,ssl_key_filename,ssl_cert_filename)){
-					fatal("couldn't accept ssl connection from %s:%d",raddr,rport);
-				}
-			}
-			handle_query(port,time(0)+child_procs_timeout);
-			link_flush_output(port);
-			_exit(0);
-		} else if (pid>0) {
-			child_procs_count++;
-		}
-	} else {
-		if(using_ssl) {
-			if(!link_ssl_wrap_accept(port,ssl_key_filename,ssl_cert_filename)){
-				debug(D_DEBUG,"couldn't accept ssl connection from %s:%d",raddr,rport);
-			}
-		}
-		handle_query(port,time(0)+child_procs_timeout);
-		link_flush_output(port);
-	}
-	link_close(port);
+	fclose(stream);
 }
 
 static void show_help(const char *cmd)
@@ -786,34 +664,28 @@ static void show_help(const char *cmd)
 	fprintf(stdout, " %-30s Rotate debug file once it reaches this size.\n", "-O,--debug-rotate-max=<bytes>");
 	fprintf(stdout, " %-30s (default 10M, 0 disables)\n", "");
 	fprintf(stdout, " %-30s Port number to listen on (default is %d)\n", "-p,--port=<port>", port);
-	fprintf(stdout, " %-30s Port number to listen for HTTPS connections.\n","-,--ssl-port=<port>");
-	fprintf(stdout, " %-30s File containing SSL certificate for HTTPS.\n","-C,--ssl-cert=<file>");
-	fprintf(stdout, " %-30s File containing SSL key for HTTPS.\n","-K,--ssl-key=<file>");
 	fprintf(stdout, " %-30s Single process mode; do not work on queries.\n", "-S,--single");
 	fprintf(stdout, " %-30s Maximum time to allow a query process to run.\n", "-T,--timeout=<time>");
 	fprintf(stdout, " %-30s (default is %ds)\n", "", child_procs_timeout);
-	fprintf(stdout, " %-30s Maximum time to allow a streaming query process to run.\n", "-T,--timeout=<time>");
-	fprintf(stdout, " %-30s (default is %ds)\n", "", streaming_procs_timeout);
 	fprintf(stdout, " %-30s Send status updates to this host. (default is\n", "-u,--update-host=<host>");
 	fprintf(stdout, " %-30s %s)\n", "", CATALOG_HOST_DEFAULT);
 	fprintf(stdout, " %-30s Send status updates at this interval.\n", "-U,--update-interval=<time>");
 	fprintf(stdout, " %-30s (default is 5m)\n", "");
 	fprintf(stdout, " %-30s Show version string\n", "-v,--version");
-	fprintf(stdout, " %-30s Select SSL port at random and write it to\n", "-Y,--ssl-port-file=<file>");
 	fprintf(stdout, " %-30s Select port at random and write it to\n", "-Z,--port-file=<file>");
 	fprintf(stdout, " %-30s this file. (default: disabled)\n", "");
 }
 
 int main(int argc, char *argv[])
 {
-	struct link *link;
-	struct link *query_port = 0;
-	struct link *query_ssl_port = 0;
+	struct link *link, *query_port = 0;
 	signed char ch;
 	time_t current;
 	int is_daemon = 0;
 	char *pidfile = NULL;
 	char *interface = NULL;
+	char raddr[LINK_ADDRESS_MAX];
+	int rport;
 
 	outgoing_host_list = list_create();
 
@@ -836,21 +708,16 @@ int main(int argc, char *argv[])
 		{"debug-file", required_argument, 0, 'o'},
 		{"debug-rotate-max", required_argument, 0, 'O'},
 		{"port", required_argument, 0, 'p'},
-		{"ssl-port", required_argument, 0, 'P'},
-		{"ssl-cert", required_argument, 0, 'C'},
-		{"ssl-key", required_argument, 0, 'K'},
 		{"single", no_argument, 0, 'S'},
 		{"timeout", required_argument, 0, 'T'},
-		{"streaming-timeout", required_argument, 0, 'Q'},
 		{"update-host", required_argument, 0, 'u'},
 		{"update-interval", required_argument, 0, 'U'},
 		{"version", no_argument, 0, 'v'},
-		{"ssl-port-file", required_argument, 0, 'Y'},
 		{"port-file", required_argument, 0, 'Z'},
 		{0,0,0,0}};
 
 
-	while((ch = getopt_long(argc, argv, "bB:C:d:hH:I:l:K:L:m:M:n:o:O:p:P:Q:ST:u:U:vZ:", long_options, NULL)) > -1) {
+	while((ch = getopt_long(argc, argv, "bB:d:hH:I:l:L:m:M:n:o:O:p:ST:u:U:vZ:", long_options, NULL)) > -1) {
 		switch (ch) {
 			case 'b':
 				is_daemon = 1;
@@ -897,24 +764,12 @@ int main(int argc, char *argv[])
 			case 'p':
 				port = atoi(optarg);
 				break;
-			case 'P':
-				ssl_port = atoi(optarg);
-				break;
-			case 'C':
-				ssl_cert_filename = optarg;
-				break;
-			case 'K':
-				ssl_key_filename = optarg;
-				break;	
 			case 'S':
 				fork_mode = 0;
 				break;
 			case 'T':
 				child_procs_timeout = string_time_parse(optarg);
 				break;
-			case 'Q':
-				streaming_procs_timeout = string_time_parse(optarg);
-				break;
 			case 'u':
 				list_push_head(outgoing_host_list, xxstrdup(optarg));
 				break;
@@ -924,10 +779,6 @@ int main(int argc, char *argv[])
 			case 'v':
 				cctools_version_print(stdout, argv[0]);
 				return 0;
-			case 'Y':
-				ssl_port_file = optarg;
-				ssl_port = 0;
-				break;
 			case 'Z':
 				port_file = optarg;
 				port = 0;
@@ -957,7 +808,7 @@ int main(int argc, char *argv[])
 	install_handler(SIGINT, shutdown_clean);
 	install_handler(SIGTERM, shutdown_clean);
 	install_handler(SIGQUIT, shutdown_clean);
-	install_handler(SIGALRM, shutdown_fast);
+	install_handler(SIGALRM, shutdown_clean);
 
 	if(!preferred_hostname) {
 		domain_name_cache_guess(hostname);
@@ -991,27 +842,6 @@ int main(int argc, char *argv[])
 			fatal("couldn't listen on TCP port %d", port);
 	}
 
-	if(ssl_port || ssl_key_filename || ssl_cert_filename) {
-
-		if(!ssl_key_filename) fatal("--ssl-key is also required for SSL.");
-		if(!ssl_cert_filename) fatal("--ssl-cert is also required for SSL.");
-
-		query_ssl_port = link_serve_address(interface, ssl_port);
-		if(query_ssl_port) {
-			if(ssl_port==0) {
-				char addr[LINK_ADDRESS_MAX];
-				link_address_local(query_ssl_port,addr,&ssl_port);
-			}
-		} else {
-			if(interface)
-				fatal("couldn't listen on SSL TCP address %s port %d: %s", interface, ssl_port,strerror(errno));
-			else
-				fatal("couldn't listen on SSL TCP port %d: %s", ssl_port,strerror(errno));
-		}
-	} else {
-		query_ssl_port = 0;
-	}
-
 	update_dgram = datagram_create_address(interface, port);
 	if(!update_dgram) {
 		if(interface)
@@ -1029,13 +859,11 @@ int main(int argc, char *argv[])
 	}
 
 	opts_write_port_file(port_file,port);
-	opts_write_port_file(ssl_port_file,ssl_port);
 
 	while(1) {
 		fd_set rfds;
 		int dfd = datagram_fd(update_dgram);
 		int lfd = link_fd(query_port);
-		int sfd = query_ssl_port ? link_fd(query_ssl_port) : -1;
 		int ufd = link_fd(update_port);
 
 		int result, maxfd;
@@ -1062,17 +890,8 @@ int main(int argc, char *argv[])
 		FD_ZERO(&rfds);
 		FD_SET(dfd, &rfds);
 		FD_SET(ufd, &rfds);
-
-		/* Only accept incoming connections if child_procs available. */
-
 		if(child_procs_count < child_procs_max) {
-			/* Accept plain HTTP */ 
 			FD_SET(lfd, &rfds);
-
-			/* Accept HTTPS if enabled */
-			if(query_ssl_port) {
-				FD_SET(sfd,&rfds);
-			}
 		}
 		maxfd = MAX(ufd,MAX(dfd, lfd)) + 1;
 
@@ -1092,19 +911,25 @@ int main(int argc, char *argv[])
 		}
 
 		if(FD_ISSET(lfd, &rfds)) {
-			link = link_accept(query_port,time(0)+5);
+			link = link_accept(query_port, time(0) + 5);
 			if(link) {
-				handle_tcp_query(link,0);
+				if(fork_mode) {
+					pid_t pid = fork();
+					if(pid == 0) {
+						link_address_remote(link, raddr, &rport);
+						change_process_title("catalog_server [%s]", raddr);
+						alarm(child_procs_timeout);
+						handle_query(link);
+						_exit(0);
+					} else if (pid>0) {
+						child_procs_count++;
+					}
+				} else {
+					handle_query(link);
+				}
+				link_close(link);
 			}
 		}
-
-		if(query_ssl_port && FD_ISSET(sfd, &rfds)) {
-			link = link_accept(query_ssl_port,time(0)+5);
-			if(link) {
-				handle_tcp_query(link,1);
-			}
-		}
-
 	}
 
 	return 1;
