@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2015- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -58,30 +58,11 @@ struct deltadb_query * deltadb_query_create()
 void deltadb_query_delete( struct deltadb_query *query )
 {
 	if(!query) return;
-
-	char *key;
-	struct jx *jobject;
-	hash_table_firstkey(query->table);
-	while(hash_table_nextkey(query->table,&key,(void**)&jobject)) {
-		jx_delete(jobject);
-	}
 	hash_table_delete(query->table);
-
 	jx_delete(query->filter_expr);
 	jx_delete(query->where_expr);
-
-	list_first_item(query->output_exprs);
-	for(struct jx *j; (j = list_next_item(query->output_exprs));) {
-		jx_delete(j);
-	}
 	list_delete(query->output_exprs);
-
-	list_first_item(query->reduce_exprs);
-	for(struct deltadb_reduction *r; (r = list_next_item(query->reduce_exprs));) {
-		deltadb_reduction_delete(r);
-	}
 	list_delete(query->reduce_exprs);
-
 	free(query);
 }
 
@@ -214,7 +195,7 @@ static void reset_reductions( struct deltadb_query *query, deltadb_scope_t scope
 	}
 }
 
-static void update_reductions( struct deltadb_query *query, const char *key, struct jx *jobject, deltadb_scope_t scope )
+static void update_reductions( struct deltadb_query *query, struct jx *jobject, deltadb_scope_t scope )
 {
 	/* Skip if the where expression doesn't match */
 	if(!deltadb_boolean_expr(query->where_expr,jobject)) return;
@@ -224,16 +205,16 @@ static void update_reductions( struct deltadb_query *query, const char *key, str
 		if(r->scope!=scope) continue;
 		struct jx *value = jx_eval(r->expr,jobject);
 		if(value && !jx_istype(value, JX_ERROR)) {
-			deltadb_reduction_update(r,key,value,scope);
+			deltadb_reduction_update(r,value,scope);
+			jx_delete(value);
 		}
-		jx_delete(value);
 	}
 }
 
 static void display_reduce_exprs( struct deltadb_query *query, time_t current )
 {
-	/* Reset all spatial reductions. */
-	reset_reductions(query,DELTADB_SCOPE_SPATIAL);
+	/* Reset all local reductions. */
+	reset_reductions(query,DELTADB_SCOPE_LOCAL);
 
 	/* For each object in the hash table: */
 
@@ -242,7 +223,7 @@ static void display_reduce_exprs( struct deltadb_query *query, time_t current )
 	hash_table_firstkey(query->table);
 	while(hash_table_nextkey(query->table,&key,(void**)&jobject)) {
 		/* Update each local reduction with its value. */
-		update_reductions(query,key,jobject,DELTADB_SCOPE_SPATIAL);
+		update_reductions(query,jobject,DELTADB_SCOPE_LOCAL);
 	}
 
 	/* Emit the current time */
@@ -258,34 +239,16 @@ static void display_reduce_exprs( struct deltadb_query *query, time_t current )
 	/* For each reduction, display the final value. */
 	list_first_item(query->reduce_exprs);
 	for(struct deltadb_reduction *r; (r = list_next_item(query->reduce_exprs));) {
-		if (r->scope == DELTADB_SCOPE_TEMPORAL) {
-			struct jx *column = jx_object(0);
-			char *key;
-			void *value;
-			struct deltadb_reduction *temporal;
-			hash_table_firstkey(r->temporal_table);
-			while(hash_table_nextkey(r->temporal_table,&key,&value)){
-				temporal = (struct deltadb_reduction *) value;
-				char *value_str = deltadb_reduction_string(temporal);
-				jx_insert_string(column, key, value_str);
-				free(value_str);
-			}
-			char *str = jx_print_string(column);
-			fprintf(query->output_stream, "%s ", str);
-			free(str);
-			jx_delete(column);
-		} else if (r->scope == DELTADB_SCOPE_SPATIAL || r->scope == DELTADB_SCOPE_GLOBAL) {
-			char *str = deltadb_reduction_string(r);
-			fprintf(query->output_stream,"%s ",str);
-			free(str);
-		}
+		char *str = deltadb_reduction_string(r);
+		fprintf(query->output_stream,"%s\n",str);
+		free(str);
 	}
 
 	fprintf(query->output_stream,"\n");
 
-	/* Reset temporal and global reductions to compute new values. */
-	reset_reductions(query,DELTADB_SCOPE_TEMPORAL);
+	/* Reset global reductions to compute new values. */
 	reset_reductions(query,DELTADB_SCOPE_GLOBAL);
+
 }
 
 static void display_output_exprs( struct deltadb_query *query, time_t current )
@@ -382,8 +345,7 @@ int deltadb_create_event( struct deltadb_query *query, const char *key, struct j
 		return 1;
 	}
 
-	update_reductions(query,key,jobject,DELTADB_SCOPE_GLOBAL);
-	update_reductions(query,key,jobject,DELTADB_SCOPE_TEMPORAL);
+	update_reductions(query,jobject,DELTADB_SCOPE_GLOBAL);
 
 	hash_table_insert(query->table,key,jobject);
 
@@ -459,8 +421,7 @@ int deltadb_merge_event( struct deltadb_query *query, const char *key, struct jx
 
 	jx_delete(update);
 
-	update_reductions(query,key,current,DELTADB_SCOPE_GLOBAL);
-	update_reductions(query,key,current,DELTADB_SCOPE_TEMPORAL);
+	update_reductions(query,current,DELTADB_SCOPE_GLOBAL);
 
 	return 1;
 }
@@ -477,8 +438,7 @@ int deltadb_update_event( struct deltadb_query *query, const char *key, const ch
 	jx_delete(jx_remove(jobject,jname));
 	jx_insert(jobject,jname,jvalue);
 
-	update_reductions(query,key,jobject,DELTADB_SCOPE_TEMPORAL);
-	update_reductions(query,key,jobject,DELTADB_SCOPE_GLOBAL);
+	update_reductions(query,jobject,DELTADB_SCOPE_GLOBAL);
 
 	if(query->display_mode==DELTADB_DISPLAY_STREAM) {
 		display_deferred_time(query);
@@ -530,9 +490,8 @@ int deltadb_time_event( struct deltadb_query *query, time_t starttime, time_t st
 	return 1;
 }
 
-int deltadb_raw_event( struct deltadb_query *query, const char *line )
+int deltadb_post_event( struct deltadb_query *query, const char *line )
 {
-	fputs(line,query->output_stream);
 	return 1;
 }
 
@@ -550,21 +509,6 @@ static int days_in_year( int y )
 	}
 }
 
-static int is_fast_query( struct deltadb_query *query )
-{
-	return query->display_mode==DELTADB_DISPLAY_STREAM && !query->filter_expr && !query->where_expr;
-}
-
-static struct deltadb_event_handlers handlers = {
-  deltadb_create_event,
-  deltadb_delete_event,
-  deltadb_update_event,
-  deltadb_merge_event,
-  deltadb_remove_event,
-  deltadb_time_event,
-  deltadb_raw_event
-};
-
 /*
 Execute a query on a single data stream.
 */
@@ -572,11 +516,7 @@ Execute a query on a single data stream.
 int deltadb_query_execute_stream( struct deltadb_query *query, FILE *stream, time_t starttime, time_t stoptime )
 {
 	query->display_next = starttime;
-	if(is_fast_query(query)) {
-		return deltadb_process_stream_fast(query,&handlers,stream,starttime,stoptime);
-	} else {
-		return deltadb_process_stream(query,&handlers,stream,starttime,stoptime);
-	}
+	return deltadb_process_stream(query,stream,starttime,stoptime);
 }
 
 /*
@@ -602,11 +542,8 @@ int deltadb_query_execute_dir( struct deltadb_query *query, const char *logdir,
 	int stopday = stoptm->tm_yday;
 
 	char *filename = string_format("%s/%d/%d.ckpt",logdir,year,day);
-	int ret = checkpoint_read(query,filename);
+	checkpoint_read(query,filename);
 	free(filename);
-	if (!ret) {
-		return 0;
-	}
 
 	while(1) {
 		char *filename = string_format("%s/%d/%d.log",logdir,year,day);
@@ -615,18 +552,12 @@ int deltadb_query_execute_dir( struct deltadb_query *query, const char *logdir,
 			file_errors += 1;
 			fprintf(stderr,"couldn't open %s: %s\n",filename,strerror(errno));
 			free(filename);
-			if (file_errors>5) {
-				return 0;
-			}
+			if (file_errors>5)
+				break;
 
 		} else {
 			free(filename);
-			int keepgoing;
-			if(is_fast_query(query)) {
-				keepgoing = deltadb_process_stream_fast(query,&handlers,file,starttime,stoptime);
-			} else {
-				keepgoing = deltadb_process_stream(query,&handlers,file,starttime,stoptime);
-			}
+			int keepgoing = deltadb_process_stream(query,file,starttime,stoptime);
 			starttime = 0;
 
 			fclose(file);
