@@ -1,50 +1,48 @@
 #include "address.h"
 #include "debug.h"
 #include "xxmalloc.h"
-#include <arpa/inet.h>
 #include <assert.h>
 #include <errno.h>
+#include <string.h>
+#include <arpa/inet.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <sys/socket.h>
 #include <unistd.h>
 
-int address_check_mode(struct addrinfo *info)
-{
+int address_check_mode( struct addrinfo *info ) {
 	assert(info);
 
 	const char *mode_str = getenv("CCTOOLS_IP_MODE");
-	if (!mode_str)
-		mode_str = "IPV4";
+	if(!mode_str) mode_str = "IPV4";
 
-	if (!strcmp(mode_str, "AUTO")) {
+	if(!strcmp(mode_str,"AUTO")) {
 		info->ai_family = AF_UNSPEC;
 		return 1;
-	} else if (!strcmp(mode_str, "IPV4")) {
+	} else if(!strcmp(mode_str,"IPV4")) {
 		info->ai_family = AF_INET;
 		return 1;
-	} else if (!strcmp(mode_str, "IPV6")) {
+	} else if(!strcmp(mode_str,"IPV6")) {
 		info->ai_family = AF_INET6;
 		return 1;
 	} else {
-		debug(D_NOTICE, "CCTOOLS_IP_MODE has invalid value (%s).  Choices are IPV4, IPV6, or AUTO", mode_str);
+		debug(D_NOTICE,"CCTOOLS_IP_MODE has invalid value (%s).  Choices are IPV4, IPV6, or AUTO",mode_str);
 		info->ai_family = AF_UNSPEC;
 		return 0;
 	}
 }
 
-int address_to_sockaddr(const char *str, int port, struct sockaddr_storage *addr, SOCKLEN_T *length)
+int address_to_sockaddr( const char *str, int port, struct sockaddr_storage *addr, SOCKLEN_T *length )
 {
 	struct addrinfo info;
 	memset(&info, 0, sizeof(struct addrinfo));
-	memset(addr, 0, sizeof(*addr));
+	memset(addr,0,sizeof(*addr));
 
 	struct sockaddr_in *ipv4 = (struct sockaddr_in *)addr;
 	struct sockaddr_in6 *ipv6 = (struct sockaddr_in6 *)addr;
 
 	address_check_mode(&info);
-	if (!str) {
+	if(!str) {
 		if (info.ai_family == AF_UNSPEC || info.ai_family == AF_INET6) {
 			// When the address is unspecified, we are
 			// attempting to bind a listening socket to
@@ -54,7 +52,7 @@ int address_to_sockaddr(const char *str, int port, struct sockaddr_storage *addr
 			ipv6->sin6_family = AF_INET6;
 			ipv6->sin6_addr = in6addr_any;
 			ipv6->sin6_port = htons(port);
-#if defined(CCTOOLS_OPSYS_DARWIN) || defined(CCTOOLS_OPSYS_FREEBSD)
+#if defined(CCTOOLS_OPSYS_DARWIN)
 			ipv6->sin6_len = sizeof(*ipv6);
 #endif
 			return AF_INET6;
@@ -63,7 +61,7 @@ int address_to_sockaddr(const char *str, int port, struct sockaddr_storage *addr
 			*length = sizeof(*ipv4);
 			ipv4->sin_family = AF_INET;
 			ipv4->sin_port = htons(port);
-#if defined(CCTOOLS_OPSYS_DARWIN) || defined(CCTOOLS_OPSYS_FREEBSD)
+#if defined(CCTOOLS_OPSYS_DARWIN)
 			ipv4->sin_len = sizeof(*ipv4);
 #endif
 			return AF_INET;
@@ -72,7 +70,7 @@ int address_to_sockaddr(const char *str, int port, struct sockaddr_storage *addr
 		*length = sizeof(*ipv4);
 		ipv4->sin_family = AF_INET;
 		ipv4->sin_port = htons(port);
-#if defined(CCTOOLS_OPSYS_DARWIN) || defined(CCTOOLS_OPSYS_FREEBSD)
+#if defined(CCTOOLS_OPSYS_DARWIN)
 		ipv4->sin_len = sizeof(*ipv4);
 #endif
 		return AF_INET;
@@ -80,7 +78,7 @@ int address_to_sockaddr(const char *str, int port, struct sockaddr_storage *addr
 		*length = sizeof(*ipv6);
 		ipv6->sin6_family = AF_INET6;
 		ipv6->sin6_port = htons(port);
-#if defined(CCTOOLS_OPSYS_DARWIN) || defined(CCTOOLS_OPSYS_FREEBSD)
+#if defined(CCTOOLS_OPSYS_DARWIN)
 		ipv6->sin6_len = sizeof(*ipv6);
 #endif
 		return AF_INET6;
@@ -89,14 +87,14 @@ int address_to_sockaddr(const char *str, int port, struct sockaddr_storage *addr
 	}
 }
 
-int address_from_sockaddr(char *str, struct sockaddr *saddr)
+int address_from_sockaddr( char *str, struct sockaddr *saddr )
 {
-	if (saddr->sa_family == AF_INET) {
+	if(saddr->sa_family==AF_INET) {
 		struct sockaddr_in *sin = (struct sockaddr_in *)saddr;
 		struct in_addr *ipaddr = &(sin->sin_addr);
 		inet_ntop(saddr->sa_family, ipaddr, str, IP_ADDRESS_MAX);
 		return 1;
-	} else if (saddr->sa_family == AF_INET6) {
+	} else if(saddr->sa_family==AF_INET6) {
 		struct sockaddr_in6 *sin = (struct sockaddr_in6 *)saddr;
 		struct in6_addr *ipaddr = &(sin->sin6_addr);
 		inet_ntop(saddr->sa_family, ipaddr, str, IP_ADDRESS_MAX);
@@ -106,12 +104,11 @@ int address_from_sockaddr(char *str, struct sockaddr *saddr)
 	}
 }
 
-static int strcount(const char *s, char c)
+static int strcount( const char *s, char c )
 {
-	int count = 0;
-	while (*s) {
-		if (*s++ == c)
-			count++;
+	int count=0;
+	while(*s) {
+		if(*s++==c) count++;
 	}
 	return count;
 }
@@ -136,37 +133,28 @@ So, we must also catch these formats:
 [100:200:300::400:500]:1234
 */
 
-int address_parse_hostport(const char *hostport, char *host, int *port, int default_port)
+int address_parse_hostport( const char *hostport, char *host, int *port, int default_port )
 {
 	*port = default_port;
 
-	int c = strcount(hostport, ':');
-	if (c == 0) {
-		strcpy(host, hostport);
+	int c = strcount(hostport,':');
+	if(c==0) {
+		strcpy(host,hostport);
 		return 1;
-	} else if (c == 1) {
-		if (sscanf(hostport, "%[^:]:%d", host, port) == 2) {
+	} else if(c==1) {
+		if(sscanf(hostport,"%[^:]:%d",host,port)==2) {
 			return 1;
 		} else {
 			return 0;
 		}
 	} else {
-		if (sscanf(hostport, "[%[^]]]:%d", host, port) == 2) {
+		if(sscanf(hostport,"[%[^]]]:%d",host,port)==2) {
 			return 1;
 		} else {
-			strcpy(host, hostport);
+			strcpy(host,hostport);
 			return 1;
 		}
 	}
 }
 
-int address_is_valid_ip(const char *str)
-{
-	struct sockaddr_storage addr;
-	SOCKLEN_T length;
-	int dummy_port = 0;
-
-	return address_to_sockaddr(str, dummy_port, &addr, &length);
-}
-
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
