@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2005- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -103,7 +103,7 @@ int main(int argc, char *argv[])
 
 		link = link_connect(addr, portnum, stoptime);
 		if(!link)
-			fatal("auth_test: couldn't connect to %s:%d: %s", hostname, portnum, strerror(errno));
+			fatal("couldn't connect to %s:%d: %s", hostname, portnum, strerror(errno));
 
 		if(auth_assert(link, &type, &subject, stoptime)) {
 			printf("server thinks I am %s %s\n", type, subject);
@@ -132,7 +132,7 @@ int main(int argc, char *argv[])
 
 			if(auth_accept(link, &type, &subject, stoptime)) {
 				time_t t = time(0);
-				link_printf(link, stoptime, "Hello %s:%s, it is now %s", type, subject, ctime(&t));	/* ctime ends with newline */
+				link_putfstring(link, "Hello %s:%s, it is now %s", stoptime, type, subject, ctime(&t));	/* ctime ends with newline */
 			} else {
 				printf("couldn't auth accept\n");
 			}
@@ -143,4 +143,4 @@ int main(int argc, char *argv[])
 	return 0;
 }
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
