@@ -1,18 +1,17 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2012- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
 
 #include "cctools.h"
 #include "debug.h"
-#include "stringtools.h"
 
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
 
-void cctools_version_print(FILE *stream, const char *cmd)
+void cctools_version_print (FILE *stream, const char *cmd)
 {
 	fprintf(stream, "%s version %s (released %s)\n", cmd, CCTOOLS_VERSION, CCTOOLS_RELEASE_DATE);
 	fprintf(stream, "\tBuilt by %s@%s on %s\n", BUILD_USER, BUILD_HOST, BUILD_DATE);
@@ -20,12 +19,7 @@ void cctools_version_print(FILE *stream, const char *cmd)
 	fprintf(stream, "\tConfiguration: %s\n", CCTOOLS_CONFIGURE_ARGUMENTS);
 }
 
-char *cctools_version_string()
-{
-	return string_format("%d.%d.%d", CCTOOLS_VERSION_MAJOR, CCTOOLS_VERSION_MINOR, CCTOOLS_VERSION_MICRO);
-}
-
-void cctools_version_debug(uint64_t type, const char *cmd)
+void cctools_version_debug (uint64_t type, const char *cmd)
 {
 	debug(type, "%s version %s (released %s)", cmd, CCTOOLS_VERSION, CCTOOLS_RELEASE_DATE);
 	debug(type, "Built by %s@%s on %s", BUILD_USER, BUILD_HOST, BUILD_DATE);
@@ -33,7 +27,7 @@ void cctools_version_debug(uint64_t type, const char *cmd)
 	debug(type, "Configuration: %s", CCTOOLS_CONFIGURE_ARGUMENTS);
 }
 
-int cctools_version_cmp(const char *v1, const char *v2)
+int cctools_version_cmp (const char *v1, const char *v2)
 {
 	int major1 = 0, minor1 = 0, micro1 = 0;
 	int major2 = 0, minor2 = 0, micro2 = 0;
@@ -49,4 +43,4 @@ int cctools_version_cmp(const char *v1, const char *v2)
 	return rc;
 }
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
