@@ -17,24 +17,22 @@
 typedef uint32_t Elf32_Addr;
 typedef uint16_t Elf32_Half;
 typedef uint32_t Elf32_Off;
-typedef int32_t Elf32_Sword;
+typedef int32_t  Elf32_Sword;
 typedef uint32_t Elf32_Word;
 
 typedef uint64_t Elf64_Addr;
 typedef uint16_t Elf64_Half;
 typedef uint64_t Elf64_Off;
 typedef uint32_t Elf64_Word;
-typedef int32_t Elf64_Sword;
+typedef int32_t  Elf64_Sword;
 
 typedef uint64_t Elf32_Xword;
-typedef int64_t Elf32_Sxword;
+typedef int64_t  Elf32_Sxword;
 typedef uint64_t Elf64_Xword;
-typedef int64_t Elf64_Sxword;
+typedef int64_t  Elf64_Sxword;
 
 #define EI_NIDENT 16
-#define ELFMAG \
-	"\x7f" \
-	"ELF"
+#define ELFMAG "\x7f" "ELF"
 
 /* indexes */
 #define EI_MAG0 0
@@ -126,93 +124,93 @@ static int elf_interp(int fd, int set, char *interp)
 		CATCH(ENOEXEC);
 
 	addr_len = info.st_size;
-	addr = mmap(NULL, addr_len, PROT_READ | (set ? PROT_WRITE : 0), MAP_SHARED, fd, 0);
+	addr = mmap(NULL, addr_len, PROT_READ|(set ? PROT_WRITE : 0), MAP_SHARED, fd, 0);
 	CATCHUNIX(addr == NULL ? -1 : 0);
 
-	if (strncmp((const char *)addr, ELFMAG, sizeof(ELFMAG) - 1) != 0)
+	if (strncmp((const char *)addr, ELFMAG, sizeof(ELFMAG)-1) != 0)
 		CATCH(ENOEXEC);
 
 	ident = (unsigned char *)addr;
 	switch (ident[EI_CLASS]) {
-	case ELFCLASS32: {
-		int i;
-		Elf32_Phdr *phdr;
-		Elf32_Ehdr *hdr = addr;
-		p16(hdr->e_type);
-		p32(hdr->e_phoff);
-		p16(hdr->e_phentsize);
-		p16(hdr->e_phnum);
+		case ELFCLASS32: {
+			int i;
+			Elf32_Phdr *phdr;
+			Elf32_Ehdr *hdr = addr;
+			p16(hdr->e_type);
+			p32(hdr->e_phoff);
+			p16(hdr->e_phentsize);
+			p16(hdr->e_phnum);
 
-		phdr = addr + sizeof(*hdr);
-		for (i = 0; i < hdr->e_phnum; i++) {
-			if ((uintptr_t)&phdr[i + 1] >= ((uintptr_t)addr + addr_len))
-				CATCH(ENOEXEC);
-			p32(phdr[i].p_type);
-			p32(phdr[i].p_offset);
-			p32(phdr[i].p_filesz);
-			if (phdr[i].p_type == PT_INTERP) {
-				const char *old = (const char *)addr + phdr[i].p_offset;
-				if (set) {
-					/* So the basic idea here is that we just add 4096
-					 * bytes (PATH_MAX) to the end of the file and point to
-					 * that. It's not that inefficient and we can skip
-					 * fixing file offsets in all the ELF headers.
-					 */
-					debug(D_DEBUG, "old interp: '%s'", old);
-					phdr[i].p_offset = addr_len;
-					phdr[i].p_filesz = PATH_MAX;
-					CATCHUNIX(pwrite(fd, interp, PATH_MAX, phdr[i].p_offset));
-				} else {
-					strcpy(interp, old);
+			phdr = addr+sizeof(*hdr);
+			for (i = 0; i < hdr->e_phnum; i++) {
+				if ((uintptr_t)&phdr[i+1] >= ((uintptr_t)addr+addr_len))
+					CATCH(ENOEXEC);
+				p32(phdr[i].p_type);
+				p32(phdr[i].p_offset);
+				p32(phdr[i].p_filesz);
+				if (phdr[i].p_type == PT_INTERP) {
+					const char *old = (const char *)addr+phdr[i].p_offset;
+					if (set) {
+						/* So the basic idea here is that we just add 4096
+						 * bytes (PATH_MAX) to the end of the file and point to
+						 * that. It's not that inefficient and we can skip
+						 * fixing file offsets in all the ELF headers.
+						 */
+						debug(D_DEBUG, "old interp: '%s'", old);
+						phdr[i].p_offset = addr_len;
+						phdr[i].p_filesz = PATH_MAX;
+						CATCHUNIX(pwrite(fd, interp, PATH_MAX, phdr[i].p_offset));
+					} else {
+						strcpy(interp, old);
+					}
+					rc = 0;
+					goto out;
 				}
-				rc = 0;
-				goto out;
 			}
+			CATCH(EINVAL);
+			break;
 		}
-		CATCH(EINVAL);
-		break;
-	}
-	case ELFCLASS64: {
-		int i;
-		Elf64_Phdr *phdr;
-		Elf64_Ehdr *hdr = addr;
-		p16(hdr->e_type);
-		p64(hdr->e_phoff);
-		p16(hdr->e_phentsize);
-		p16(hdr->e_phnum);
+		case ELFCLASS64: {
+			int i;
+			Elf64_Phdr *phdr;
+			Elf64_Ehdr *hdr = addr;
+			p16(hdr->e_type);
+			p64(hdr->e_phoff);
+			p16(hdr->e_phentsize);
+			p16(hdr->e_phnum);
 
-		phdr = addr + sizeof(*hdr);
-		for (i = 0; i < hdr->e_phnum; i++) {
-			if ((uintptr_t)&phdr[i + 1] >= ((uintptr_t)addr + addr_len))
-				CATCH(ENOEXEC);
-			p32(phdr[i].p_type);
-			p64(phdr[i].p_offset);
-			p64(phdr[i].p_filesz);
-			if (phdr[i].p_type == PT_INTERP) {
-				const char *old = (const char *)addr + phdr[i].p_offset;
-				if (set) {
-					/* So the basic idea here is that we just add 4096
-					 * bytes (PATH_MAX) to the end of the file and point to
-					 * that. It's not that inefficient and we can skip
-					 * fixing file offsets in all the ELF headers.
-					 */
-					debug(D_DEBUG, "old interp: '%s'", old);
-					phdr[i].p_offset = addr_len;
-					phdr[i].p_filesz = PATH_MAX;
-					CATCHUNIX(pwrite(fd, interp, PATH_MAX, phdr[i].p_offset));
-				} else {
-					strcpy(interp, old);
+			phdr = addr+sizeof(*hdr);
+			for (i = 0; i < hdr->e_phnum; i++) {
+				if ((uintptr_t)&phdr[i+1] >= ((uintptr_t)addr+addr_len))
+					CATCH(ENOEXEC);
+				p32(phdr[i].p_type);
+				p64(phdr[i].p_offset);
+				p64(phdr[i].p_filesz);
+				if (phdr[i].p_type == PT_INTERP) {
+					const char *old = (const char *)addr+phdr[i].p_offset;
+					if (set) {
+						/* So the basic idea here is that we just add 4096
+						 * bytes (PATH_MAX) to the end of the file and point to
+						 * that. It's not that inefficient and we can skip
+						 * fixing file offsets in all the ELF headers.
+						 */
+						debug(D_DEBUG, "old interp: '%s'", old);
+						phdr[i].p_offset = addr_len;
+						phdr[i].p_filesz = PATH_MAX;
+						CATCHUNIX(pwrite(fd, interp, PATH_MAX, phdr[i].p_offset));
+					} else {
+						strcpy(interp, old);
+					}
+					rc = 0;
+					goto out;
 				}
-				rc = 0;
-				goto out;
 			}
+			CATCH(EINVAL);
+			break;
 		}
-		CATCH(EINVAL);
-		break;
-	}
-	default:
-		CATCH(ENOEXEC);
-		break;
+		default:
+			CATCH(ENOEXEC);
+			break;
 	}
 
 	rc = 0;
@@ -229,6 +227,7 @@ int elf_get_interp(int fd, char *interp)
 	return elf_interp(fd, 0, interp);
 }
 
+
 int elf_set_interp(int fd, const char *interp)
 {
 	char path[PATH_MAX] = "";
@@ -240,4 +239,4 @@ int elf_set_interp(int fd, const char *interp)
 	return elf_interp(fd, 1, path);
 }
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
