@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2010- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -18,35 +18,35 @@ See the file COPYING for details.
 #include <sys/types.h>
 #include <unistd.h>
 
+
 int find_executable(const char *exe_name, const char *env_path_var, char *exe_path, int max_length)
 {
 	char *env_paths;
 	char *cur_path;
 
-	if (access(exe_name, R_OK | X_OK) == 0) {
+	if(access(exe_name, R_OK | X_OK) == 0) {
 		snprintf(exe_path, max_length, "%s", exe_name);
 		return 1;
 	}
 
-	if (!getenv(env_path_var))
+	if(!getenv(env_path_var))
 		return 0;
 
 	env_paths = xxstrdup(getenv(env_path_var));
 
-	for (cur_path = strtok(env_paths, ":"); cur_path; cur_path = strtok(NULL, ":")) {
+	for(cur_path = strtok(env_paths, ":"); cur_path; cur_path = strtok(NULL, ":")) {
 		snprintf(exe_path, max_length, "%s/%s", cur_path, exe_name);
-		if (access(exe_path, R_OK | X_OK) == 0)
+		if(access(exe_path, R_OK | X_OK) == 0)
 			goto fe_cleanup;
 	}
 
-fe_cleanup:
+	  fe_cleanup:
 	free(env_paths);
 
 	return cur_path != NULL;
 }
 
-int env_replace(const char *infile, const char *outfile)
-{
+int env_replace( const char *infile, const char *outfile ){
 	FILE *INPUT = fopen(infile, "r");
 	if (INPUT == NULL) {
 		debug(D_ERROR, "unable to open %s: %s", infile, strerror(errno));
@@ -58,13 +58,14 @@ int env_replace(const char *infile, const char *outfile)
 		debug(D_ERROR, "unable to open %s: %s", outfile, strerror(errno));
 		return 1;
 	}
-
+	
 	char variable[1024];
 	int var_index = 0;
 	int valid_var = 0;
 
-	int c = fgetc(INPUT);
-	while (c != EOF) {
+	char c = fgetc(INPUT);
+	while (c != EOF)
+	{
 		if (c == '$') {
 			valid_var = 1;
 		} else if (valid_var && (isalpha(c) || (c == '_') || (var_index > 1 && isdigit(c)))) {
@@ -99,24 +100,4 @@ int env_replace(const char *infile, const char *outfile)
 	return 0;
 }
 
-const char *system_tmp_dir(const char *override_tmp_dir)
-{
-	const char *tmp_dir;
-	if (override_tmp_dir) {
-		return override_tmp_dir;
-	} else if ((tmp_dir = getenv("CCTOOLS_TEMP")) && access(tmp_dir, R_OK | W_OK | X_OK) == 0) {
-		return tmp_dir;
-	} else if ((tmp_dir = getenv("_CONDOR_SCRATCH_DIR")) && access(tmp_dir, R_OK | W_OK | X_OK) == 0) {
-		return tmp_dir;
-	} else if ((tmp_dir = getenv("TMPDIR")) && access(tmp_dir, R_OK | W_OK | X_OK) == 0) {
-		return tmp_dir;
-	} else if ((tmp_dir = getenv("TEMP")) && access(tmp_dir, R_OK | W_OK | X_OK) == 0) {
-		return tmp_dir;
-	} else if ((tmp_dir = getenv("TMP")) && access(tmp_dir, R_OK | W_OK | X_OK) == 0) {
-		return tmp_dir;
-	} else {
-		return "/tmp";
-	}
-}
-
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
