@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2015- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -76,10 +76,9 @@ struct jx_item {
 /** JX key-value pairs used by @ref JX_OBJECT and @ref jx.pairs */
 
 struct jx_pair {
-	unsigned line;
 	struct jx      *key;	/**< key of this pair */
 	struct jx      *value;  /**< value of this pair */
-	struct jx_comprehension *comp;
+	unsigned line;
 	struct jx_pair *next;   /**< pointer to next pair */
 };
 
@@ -101,7 +100,6 @@ typedef enum {
 	JX_OP_LOOKUP,
 	JX_OP_CALL,
 	JX_OP_SLICE,
-	JX_OP_DOT,
 	JX_OP_INVALID,
 } jx_operator_t;
 
@@ -151,17 +149,11 @@ struct jx * jx_string_nocopy( char *string_value );
 /** Create a JX string value using prinf style formatting.  @param fmt A printf-style format string, followed by matching arguments.  @return A JX string value. */
 struct jx * jx_format( const char *fmt, ... );
 
-/** Create a JX symbol.
-Note that symbols are an extension to the JSON standard. A symbol is a reference to an external variable, which can be resolved by using @ref jx_eval
-@param symbol_name A C string.
-@return A JX expression.
+/** Create a JX symbol. Note that symbols are an extension to the JSON standard. A symbol is a reference to an external variable, which can be resolved by using @ref jx_eval. @param symbol_name A C string. @return A JX expression.
 */
 struct jx * jx_symbol( const char *symbol_name );
 
-/** Create a JX_ERROR.
-@param err The associated data for the error. This should be a string description of the error.
-@return A JX error value.
-*/
+/** Create a JX_ERROR. @param err The associated data for the error. This should be a string description of the error. @return A JX error value. */
 struct jx * jx_error( struct jx *err );
 
 /** Create a JX array.  @param items A linked list of @ref jx_item values.  @return A JX array. */
@@ -212,9 +204,6 @@ int jx_isatomic( struct jx *j );
 /** Test an expression for the boolean value TRUE.  @param j An expression to test.  @return True if the expression is boolean and true. */
 int jx_istrue( struct jx *j );
 
-/** Test an expression for the boolean value FALSE @param j An expression to test.  @return True if the expression is boolean and false. */
-int jx_isfalse( struct jx *j );
-
 int jx_comprehension_equals(struct jx_comprehension *j, struct jx_comprehension *k);
 int jx_item_equals(struct jx_item *j, struct jx_item *k);
 int jx_pair_equals(struct jx_pair *j, struct jx_pair *k);
@@ -308,7 +297,7 @@ struct jx *jx_array_shift(struct jx *array);
 /** Determine if an expression is constant.  Traverses the expression recursively, and returns true if it consists only of constant values, arrays, and objects. @param j The expression to evaluate.  @return True if constant. */
 int jx_is_constant( struct jx *j );
 
-/** Export a jx object into the current environment using setenv(). @param j A JX_OBJECT. */
+/** Export a jx object as a set of environment variables.  @param j A JX_OBJECT. */
 void jx_export( struct jx *j );
 
 /** Iterate over the values in an array.
@@ -392,4 +381,4 @@ struct jx *jx_merge(struct jx *j, ...);
 
 #endif
 
-/*vim: set noexpandtab tabstop=8: */
+/*vim: set noexpandtab tabstop=4: */
