@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2015- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -22,10 +22,6 @@ char * jx_print_string( struct jx *j );
 
 void jx_print_stream( struct jx *j, FILE *file );
 
-/** Print a JX object as shell environment variables.  @param j A JX expression.  @param file A standard IO stream. */
-
-void jx_print_shell( struct jx *j, FILE *file );
-
 /** Print a JX expression to a buffer. @param j A JX expression. @param buffer The buffer for output. @see buffer.h */
 
 void jx_print_buffer( struct jx *j, buffer_t *buffer);
@@ -48,6 +44,4 @@ const char * jx_type_string( jx_type_t type );
 
 // internal function for printing list comprehension expressions
 void jx_comprehension_print(struct jx_comprehension *comp, buffer_t *b);
-
-
 #endif
