@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2005- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -68,13 +68,6 @@ link_close(link);
 */
 struct link *link_connect(const char *addr, int port, time_t stoptime);
 
-/** Wrap a connect link with an ssl context and state
-@param link A link returned from @ref link_connect
-@param sni_hostname Optional domainame for tls routing.
-@return 0 on failure, 1 on success
-*/
-int link_ssl_wrap_connect(struct link *link, const char *sni_hostname);
-
 /** Turn a FILE* into a link.  Useful when trying to poll both remote and local connections using @ref link_poll
 @param file File to create the link from.
 @return On success, returns a pointer to a link object.  On failure, returns a null pointer with errno set appropriately.
@@ -112,15 +105,6 @@ Functions like @ref link_serve, except that the server will only be visible on t
 */
 struct link *link_serve_address(const char *addr, int port);
 
-
-/** Prepare to accept connections on one network interface.
-Functions like @ref link_serve, except that the server will only be visible on the given network interface.
-@param low The low port in a range to listen on (inclusive).
-@param high The high port in a range to listen on (inclusive).
-@return link A server endpoint that can be passed to @ref link_accept, or null on failure.
-*/
-struct link *link_serve_address_range(const char *addr, int low, int high);
-
 /** Prepare to accept connections on one network interface.
 Functions like @ref link_serve, except that the server will only be visible on the given network interface and allows for a port range.
 @param addr IP address of the network interface.
@@ -137,17 +121,6 @@ struct link *link_serve_addrrange(const char *addr, int low, int high);
 */
 struct link *link_accept(struct link *parent, time_t stoptime);
 
-
-/** Wrap an accepted link with an ssl context.
-If successful, the connection is now encrypted.
-@param lnk A link returned from @ref link_accept
-@param key   The ssl key of the server.
-@param cert  The ssl cert of the server.
-@return 0 on failure, 1 on success
-*/
-int link_ssl_wrap_accept(struct link *lnk, const char *key, const char *cert);
-
-
 /** Read data from a connection.
 This call will block until the given number of bytes have been read,
 or the connection is dropped.
@@ -210,23 +183,23 @@ ssize_t link_putlstring(struct link *link, const char *str, size_t len, time_t s
 /** Write formatted data to a connection. All data is written until finished
   * or an error is encountered.
 @param link The link to write.
-@param stoptime The time at which to abort.
 @param fmt A pointer to the data.
+@param stoptime The time at which to abort.
 @param ... Format arguments.
 @return The number of bytes actually written, or less than zero on error.
 */
-ssize_t link_printf(struct link *link, time_t stoptime, const char *fmt, ...)
-  __attribute__ (( format(printf,3,4) )) ;
+ssize_t link_putfstring(struct link *link, const char *fmt, time_t stoptime, ...)
+  __attribute__ (( format(printf,2,4) )) ;
 
 /** Write formatted data to a connection. All data is written until finished
   * or an error is encountered.
 @param link The link to write.
-@param stoptime The time at which to abort.
 @param fmt A pointer to the data.
+@param stoptime The time at which to abort.
 @param va Format arguments.
 @return The number of bytes actually written, or less than zero on error.
 */
-ssize_t link_vprintf(struct link *link, time_t stoptime, const char *fmt, va_list va);
+ssize_t link_putvfstring(struct link *link, const char *fmt, time_t stoptime, va_list va);
 
 /** Block until a link is readable or writable.
 @param link The link to wait on.
@@ -300,23 +273,6 @@ int link_readline(struct link *link, char *line, size_t length, time_t stoptime)
 */
 int link_fd(struct link *link);
 
-/** Enable output buffering for link_printf.
-@param link The link to modify.
-@param size The number of bytes to buffer.  Zero disables buffering and flushes pending output.
-*/
-int link_buffer_output(struct link *link, size_t size );
-
-/** Flush buffered output from link_printf.
-@param link The link to modify.
-*/
-int link_flush_output(struct link *link );
-
-/** Whether the link is using ssl.
-@param link The link to examine.
-@return True if ssl context has been created, False otherwise
-*/
-int link_using_ssl(struct link *link);
-
 int link_keepalive(struct link *link, int onoff);
 
 int link_nonblocking(struct link *link, int onoff);
@@ -391,13 +347,6 @@ Wait for a activity on a an array of links.
 
 int link_poll(struct link_info *array, int nlinks, int msec);
 
-/** Get the number of bytes in the output buffer of a link.
-@param link The link to examine.
-@return The number of bytes in the output buffer of a link.
-*/
-int link_get_buffer_bytes(struct link *link);
-
-
 int errno_is_temporary(int e);
 
 #endif
