@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2018- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -46,8 +46,6 @@ all of our code, we simply insert these defines to
 transparently modify the linker namespace we are using.
 */
 
-#ifndef DOXYGEN
-
 #define list_create			cctools_list_create
 #define list_destroy			cctools_list_destroy
 #define list_length			cctools_list_length
@@ -84,8 +82,6 @@ transparently modify the linker namespace we are using.
 #define list_first_item			cctools_list_first_item
 #define list_next_item			cctools_list_next_item
 
-#endif
-
 /** Create an empty linked list.
  * @returns A pointer to the newly created list.
  */
@@ -255,15 +251,6 @@ Note that this function does not delete the list itself.
 
 void list_free(struct list *list);
 
-/** Delete every item contained within this list,
-using the provided function.
-Note that this function does not delete the list itself.
-@param list The list to free.
-@param delete_func The function to delete items with.
-*/
-
-void list_clear(struct list *list, void (*delete_func)(void*item) );
-
 /** Splice two lists together.
 @param top A linked list that will be destroyed in the process.
 @param bottom A linked list that will be destroyed in the process.
@@ -315,12 +302,6 @@ int list_push_tail(struct list *list, void *item);
 */
 void *list_pop_tail(struct list *list);
 
-/** Move the list head to the tail
-@param list The list to rotate
-@return The old list head, new tail
-*/
-void *list_rotate(struct list *list);
-
 /** Peek at the list tail.
 @param list The list to peek.
 @return The item at the list tail, or null if list is empty.
@@ -329,7 +310,7 @@ void *list_peek_tail(struct list *list);
 
 /** Peek at the current element in the iteration.
 @param list The list to peek.
-@return The item at the current internal iterator, or null if list is empty.
+@return The item at the list head, or null if list is empty.
 */
 void *list_peek_current(struct list *list);
 
@@ -378,7 +359,7 @@ void list_first_item(struct list *list);
 This function returns the current list item,
 and advances the internal iterator to the next item.
 @param list The list to traverse.
-@return The current item in the list, NULL if end of list.
+@return The current item in the list.
 */
 
 void *list_next_item(struct list *list);
@@ -407,18 +388,4 @@ int list_iterate_reverse(struct list *list, list_op_t op, const void *arg);
 */
 struct list *list_sort(struct list *list, int (*comparator) (const void *, const void *));
 
-/** Macro to iterate over a list in the most common case.
-Note that a statement or code block must follow the macro, like this:
-
-<pre>
-char *s;
-
-LIST_ITERATE( list, s ) {
-	printf("%s\n",s);
-}
-</pre>
-*/
-
-#define LIST_ITERATE( list, item ) list_first_item(list); while((item=list_next_item(list)))
-
 #endif
