@@ -1,15 +1,15 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2008- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
 
-#if defined(CCTOOLS_OPSYS_DARWIN) || defined(CCTOOLS_OPSYS_FREEBSD)
+#if defined(CCTOOLS_OPSYS_DARWIN)
 
+#include <unistd.h>
 #include <stdlib.h>
 #include <sys/sysctl.h>
 #include <sys/types.h>
-#include <unistd.h>
 
 void load_average_get(double *avg)
 {
@@ -21,7 +21,7 @@ int load_average_get_cpus()
 {
 	int n;
 	size_t size = sizeof(n);
-	if (sysctlbyname("hw.physicalcpu", &n, &size, 0, 0) == 0) {
+	if(sysctlbyname("hw.physicalcpu", &n, &size, 0, 0) == 0) {
 		return n;
 	} else {
 		return 1;
@@ -33,15 +33,15 @@ int load_average_get_cpus()
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "string_set.h"
 #include "stringtools.h"
+#include "string_set.h"
 
 void load_average_get(double *avg)
 {
 	FILE *f;
 	avg[0] = avg[1] = avg[2] = 0;
 	f = fopen("/proc/loadavg", "r");
-	if (f) {
+	if(f) {
 		fscanf(f, "%lf %lf %lf", &avg[0], &avg[1], &avg[2]);
 		fclose(f);
 	}
@@ -52,18 +52,16 @@ int load_average_get_cpus()
 	struct string_set *cores;
 	cores = string_set_create(0, 0);
 
-	for (int i = 0;; i++) {
+	for (int i = 0; ; i++) {
 		char *p = string_format("/sys/devices/system/cpu/cpu%u/topology/thread_siblings", i);
 		FILE *f = fopen(p, "r");
 		free(p);
-		if (!f)
-			break;
+		if (!f) break;
 
 		char line[1024];
 		int rc = fscanf(f, "%1023s", line);
 		fclose(f);
-		if (rc != 1)
-			break;
+		if (rc != 1) break;
 
 		string_set_push(cores, line);
 	}
@@ -91,4 +89,4 @@ int load_average_get_cpus()
 
 #endif
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
