@@ -32,15 +32,15 @@ documentation and/or software.
 #include <fcntl.h>
 #include <unistd.h>
 
-#include <dirent.h>
-#include <errno.h>
-#include <stdint.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <sys/mman.h>
 #include <sys/stat.h>
 
+#include <errno.h>
+#include <stdio.h>
+#include <stdint.h>
+#include <stdlib.h>
+#include <string.h>
+
 #define S11 7
 #define S12 12
 #define S13 17
@@ -58,70 +58,11 @@ documentation and/or software.
 #define S43 15
 #define S44 21
 
-static const uint8_t PADDING[64] = {0x80,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0,
-		0};
+static const uint8_t PADDING[64] = {
+	0x80, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
+};
 
 /* F, G, H and I are basic MD5 functions.
  */
@@ -132,39 +73,36 @@ static const uint8_t PADDING[64] = {0x80,
 
 /* ROTATE_LEFT rotates x left n bits.
  */
-#define ROTATE_LEFT(x, n) (((x) << (n)) | ((x) >> (32 - (n))))
+#define ROTATE_LEFT(x, n) (((x) << (n)) | ((x) >> (32-(n))))
 
 /* FF, GG, HH, and II transformations for rounds 1, 2, 3, and 4.
 Rotation is separate from addition to prevent recomputation.
  */
-#define FF(a, b, c, d, x, s, ac) \
-	{ \
-		(a) += F((b), (c), (d)) + (x) + (uint32_t)(ac); \
-		(a) = ROTATE_LEFT((a), (s)); \
-		(a) += (b); \
-	}
-#define GG(a, b, c, d, x, s, ac) \
-	{ \
-		(a) += G((b), (c), (d)) + (x) + (uint32_t)(ac); \
-		(a) = ROTATE_LEFT((a), (s)); \
-		(a) += (b); \
-	}
-#define HH(a, b, c, d, x, s, ac) \
-	{ \
-		(a) += H((b), (c), (d)) + (x) + (uint32_t)(ac); \
-		(a) = ROTATE_LEFT((a), (s)); \
-		(a) += (b); \
-	}
-#define II(a, b, c, d, x, s, ac) \
-	{ \
-		(a) += I((b), (c), (d)) + (x) + (uint32_t)(ac); \
-		(a) = ROTATE_LEFT((a), (s)); \
-		(a) += (b); \
-	}
+#define FF(a, b, c, d, x, s, ac) { \
+ (a) += F ((b), (c), (d)) + (x) + (uint32_t)(ac); \
+ (a) = ROTATE_LEFT ((a), (s)); \
+ (a) += (b); \
+  }
+#define GG(a, b, c, d, x, s, ac) { \
+ (a) += G ((b), (c), (d)) + (x) + (uint32_t)(ac); \
+ (a) = ROTATE_LEFT ((a), (s)); \
+ (a) += (b); \
+  }
+#define HH(a, b, c, d, x, s, ac) { \
+ (a) += H ((b), (c), (d)) + (x) + (uint32_t)(ac); \
+ (a) = ROTATE_LEFT ((a), (s)); \
+ (a) += (b); \
+  }
+#define II(a, b, c, d, x, s, ac) { \
+ (a) += I ((b), (c), (d)) + (x) + (uint32_t)(ac); \
+ (a) = ROTATE_LEFT ((a), (s)); \
+ (a) += (b); \
+  }
 
 /* MD5 initialization. Begins an MD5 operation, writing a new context.
  */
-void md5_init(md5_context_t *context)
+void md5_init(context)
+	 md5_context_t *context;	/* context */
 {
 	context->count[0] = context->count[1] = 0;
 	/* Load magic initialization constants.
@@ -178,11 +116,14 @@ void md5_init(md5_context_t *context)
 /* Encodes input (uint32_t) into output (unsigned char). Assumes len is
   a multiple of 4.
  */
-static void Encode(uint8_t *output, uint32_t *input, size_t len)
+static void Encode(output, input, len)
+	 uint8_t *output;
+	 uint32_t *input;
+	 size_t len;
 {
 	size_t i, j;
 
-	for (i = 0, j = 0; j < len; i++, j += 4) {
+	for(i = 0, j = 0; j < len; i++, j += 4) {
 		output[j] = (input[i] & 0xff);
 		output[j + 1] = ((input[i] >> 8) & 0xff);
 		output[j + 2] = ((input[i] >> 16) & 0xff);
@@ -193,17 +134,22 @@ static void Encode(uint8_t *output, uint32_t *input, size_t len)
 /* Decodes input (unsigned char) into output (uint32_t). Assumes len is
   a multiple of 4.
  */
-static void Decode(uint32_t *output, uint8_t *input, size_t len)
+static void Decode(output, input, len)
+	 uint32_t *output;
+	 uint8_t *input;
+	 size_t len;
 {
 	size_t i, j;
 
-	for (i = 0, j = 0; j < len; i++, j += 4)
-		output[i] = ((uint32_t)input[j]) | (((uint32_t)input[j + 1]) << 8) | (((uint32_t)input[j + 2]) << 16) | (((uint32_t)input[j + 3]) << 24);
+	for(i = 0, j = 0; j < len; i++, j += 4)
+		output[i] = ((uint32_t) input[j]) | (((uint32_t) input[j + 1]) << 8) | (((uint32_t) input[j + 2]) << 16) | (((uint32_t) input[j + 3]) << 24);
 }
 
 /* MD5 basic transformation. Transforms state based on block.
  */
-static void MD5Transform(uint32_t state[4], uint8_t block[64])
+static void MD5Transform(state, block)
+	 uint32_t state[4];
+	 uint8_t block[64];
 {
 	uint32_t a = state[0], b = state[1], c = state[2], d = state[3], x[16];
 
@@ -220,64 +166,64 @@ static void MD5Transform(uint32_t state[4], uint8_t block[64])
 	FF(b, c, d, a, x[7], S14, 0xfd469501);	/* 8 */
 	FF(a, b, c, d, x[8], S11, 0x698098d8);	/* 9 */
 	FF(d, a, b, c, x[9], S12, 0x8b44f7af);	/* 10 */
-	FF(c, d, a, b, x[10], S13, 0xffff5bb1); /* 11 */
-	FF(b, c, d, a, x[11], S14, 0x895cd7be); /* 12 */
-	FF(a, b, c, d, x[12], S11, 0x6b901122); /* 13 */
-	FF(d, a, b, c, x[13], S12, 0xfd987193); /* 14 */
-	FF(c, d, a, b, x[14], S13, 0xa679438e); /* 15 */
-	FF(b, c, d, a, x[15], S14, 0x49b40821); /* 16 */
+	FF(c, d, a, b, x[10], S13, 0xffff5bb1);	/* 11 */
+	FF(b, c, d, a, x[11], S14, 0x895cd7be);	/* 12 */
+	FF(a, b, c, d, x[12], S11, 0x6b901122);	/* 13 */
+	FF(d, a, b, c, x[13], S12, 0xfd987193);	/* 14 */
+	FF(c, d, a, b, x[14], S13, 0xa679438e);	/* 15 */
+	FF(b, c, d, a, x[15], S14, 0x49b40821);	/* 16 */
 
 	/* Round 2 */
 	GG(a, b, c, d, x[1], S21, 0xf61e2562);	/* 17 */
 	GG(d, a, b, c, x[6], S22, 0xc040b340);	/* 18 */
-	GG(c, d, a, b, x[11], S23, 0x265e5a51); /* 19 */
+	GG(c, d, a, b, x[11], S23, 0x265e5a51);	/* 19 */
 	GG(b, c, d, a, x[0], S24, 0xe9b6c7aa);	/* 20 */
 	GG(a, b, c, d, x[5], S21, 0xd62f105d);	/* 21 */
 	GG(d, a, b, c, x[10], S22, 0x2441453);	/* 22 */
-	GG(c, d, a, b, x[15], S23, 0xd8a1e681); /* 23 */
+	GG(c, d, a, b, x[15], S23, 0xd8a1e681);	/* 23 */
 	GG(b, c, d, a, x[4], S24, 0xe7d3fbc8);	/* 24 */
 	GG(a, b, c, d, x[9], S21, 0x21e1cde6);	/* 25 */
-	GG(d, a, b, c, x[14], S22, 0xc33707d6); /* 26 */
+	GG(d, a, b, c, x[14], S22, 0xc33707d6);	/* 26 */
 	GG(c, d, a, b, x[3], S23, 0xf4d50d87);	/* 27 */
 	GG(b, c, d, a, x[8], S24, 0x455a14ed);	/* 28 */
-	GG(a, b, c, d, x[13], S21, 0xa9e3e905); /* 29 */
+	GG(a, b, c, d, x[13], S21, 0xa9e3e905);	/* 29 */
 	GG(d, a, b, c, x[2], S22, 0xfcefa3f8);	/* 30 */
 	GG(c, d, a, b, x[7], S23, 0x676f02d9);	/* 31 */
-	GG(b, c, d, a, x[12], S24, 0x8d2a4c8a); /* 32 */
+	GG(b, c, d, a, x[12], S24, 0x8d2a4c8a);	/* 32 */
 
 	/* Round 3 */
 	HH(a, b, c, d, x[5], S31, 0xfffa3942);	/* 33 */
 	HH(d, a, b, c, x[8], S32, 0x8771f681);	/* 34 */
-	HH(c, d, a, b, x[11], S33, 0x6d9d6122); /* 35 */
-	HH(b, c, d, a, x[14], S34, 0xfde5380c); /* 36 */
+	HH(c, d, a, b, x[11], S33, 0x6d9d6122);	/* 35 */
+	HH(b, c, d, a, x[14], S34, 0xfde5380c);	/* 36 */
 	HH(a, b, c, d, x[1], S31, 0xa4beea44);	/* 37 */
 	HH(d, a, b, c, x[4], S32, 0x4bdecfa9);	/* 38 */
 	HH(c, d, a, b, x[7], S33, 0xf6bb4b60);	/* 39 */
-	HH(b, c, d, a, x[10], S34, 0xbebfbc70); /* 40 */
-	HH(a, b, c, d, x[13], S31, 0x289b7ec6); /* 41 */
+	HH(b, c, d, a, x[10], S34, 0xbebfbc70);	/* 40 */
+	HH(a, b, c, d, x[13], S31, 0x289b7ec6);	/* 41 */
 	HH(d, a, b, c, x[0], S32, 0xeaa127fa);	/* 42 */
 	HH(c, d, a, b, x[3], S33, 0xd4ef3085);	/* 43 */
 	HH(b, c, d, a, x[6], S34, 0x4881d05);	/* 44 */
 	HH(a, b, c, d, x[9], S31, 0xd9d4d039);	/* 45 */
-	HH(d, a, b, c, x[12], S32, 0xe6db99e5); /* 46 */
-	HH(c, d, a, b, x[15], S33, 0x1fa27cf8); /* 47 */
+	HH(d, a, b, c, x[12], S32, 0xe6db99e5);	/* 46 */
+	HH(c, d, a, b, x[15], S33, 0x1fa27cf8);	/* 47 */
 	HH(b, c, d, a, x[2], S34, 0xc4ac5665);	/* 48 */
 
 	/* Round 4 */
 	II(a, b, c, d, x[0], S41, 0xf4292244);	/* 49 */
 	II(d, a, b, c, x[7], S42, 0x432aff97);	/* 50 */
-	II(c, d, a, b, x[14], S43, 0xab9423a7); /* 51 */
+	II(c, d, a, b, x[14], S43, 0xab9423a7);	/* 51 */
 	II(b, c, d, a, x[5], S44, 0xfc93a039);	/* 52 */
-	II(a, b, c, d, x[12], S41, 0x655b59c3); /* 53 */
+	II(a, b, c, d, x[12], S41, 0x655b59c3);	/* 53 */
 	II(d, a, b, c, x[3], S42, 0x8f0ccc92);	/* 54 */
-	II(c, d, a, b, x[10], S43, 0xffeff47d); /* 55 */
+	II(c, d, a, b, x[10], S43, 0xffeff47d);	/* 55 */
 	II(b, c, d, a, x[1], S44, 0x85845dd1);	/* 56 */
 	II(a, b, c, d, x[8], S41, 0x6fa87e4f);	/* 57 */
-	II(d, a, b, c, x[15], S42, 0xfe2ce6e0); /* 58 */
+	II(d, a, b, c, x[15], S42, 0xfe2ce6e0);	/* 58 */
 	II(c, d, a, b, x[6], S43, 0xa3014314);	/* 59 */
-	II(b, c, d, a, x[13], S44, 0x4e0811a1); /* 60 */
+	II(b, c, d, a, x[13], S44, 0x4e0811a1);	/* 60 */
 	II(a, b, c, d, x[4], S41, 0xf7537e82);	/* 61 */
-	II(d, a, b, c, x[11], S42, 0xbd3af235); /* 62 */
+	II(d, a, b, c, x[11], S42, 0xbd3af235);	/* 62 */
 	II(c, d, a, b, x[2], S43, 0x2ad7d2bb);	/* 63 */
 	II(b, c, d, a, x[9], S44, 0xeb86d391);	/* 64 */
 
@@ -294,13 +240,11 @@ static void MD5Transform(uint32_t state[4], uint8_t block[64])
 /* MD5 block update operation. Continues an MD5 message-digest
   operation, processing another message block, and updating the
   context.
-
-*context context
-*input	 input block
-inputLen length of input block
-
-*/
-void md5_update(md5_context_t *context, const void *input, size_t inputLen)
+ */
+void md5_update(context, input, inputLen)
+	 md5_context_t *context;	/* context */
+	 const void *input;	/* input block */
+	 size_t inputLen;	/* length of input block */
 {
 	size_t i, index, partLen;
 
@@ -308,33 +252,36 @@ void md5_update(md5_context_t *context, const void *input, size_t inputLen)
 	index = ((context->count[0] >> 3) & 0x3F);
 
 	/* Update number of bits */
-	if ((context->count[0] += ((uint32_t)inputLen << 3)) < ((uint32_t)inputLen << 3))
+	if((context->count[0] += ((uint32_t) inputLen << 3))
+	   < ((uint32_t) inputLen << 3))
 		context->count[1]++;
-	context->count[1] += ((uint32_t)inputLen >> 29);
+	context->count[1] += ((uint32_t) inputLen >> 29);
 
 	partLen = 64 - index;
 
 	/* Transform as many times as possible.
 	 */
-	if (inputLen >= partLen) {
+	if(inputLen >= partLen) {
 		memcpy(&context->buffer[index], input, partLen);
 		MD5Transform(context->state, context->buffer);
 
-		for (i = partLen; i + 63 < inputLen; i += 64)
-			MD5Transform(context->state, (uint8_t *)input + i);
+		for(i = partLen; i + 63 < inputLen; i += 64)
+			MD5Transform(context->state, (uint8_t *)input+i);
 
 		index = 0;
 	} else
 		i = 0;
 
 	/* Buffer remaining input */
-	memcpy(&context->buffer[index], (uint8_t *)input + i, inputLen - i);
+	memcpy(&context->buffer[index], (uint8_t *)input+i, inputLen - i);
 }
 
 /* MD5 finalization. Ends an MD5 message-digest operation, writing the
   the message digest and zeroizing the context.
  */
-void md5_final(unsigned char digest[16], md5_context_t *context)
+void md5_final(digest, context)
+	 unsigned char digest[16];	/* message digest */
+	 md5_context_t *context;	/* context */
 {
 	uint8_t bits[8];
 	size_t index, padLen;
@@ -344,7 +291,7 @@ void md5_final(unsigned char digest[16], md5_context_t *context)
 
 	/* Pad out to 56 mod 64.
 	 */
-	index = (unsigned int)((context->count[0] >> 3) & 0x3f);
+	index = (unsigned int) ((context->count[0] >> 3) & 0x3f);
 	padLen = (index < 56) ? (56 - index) : (120 - index);
 	md5_update(context, PADDING, padLen);
 
@@ -356,7 +303,7 @@ void md5_final(unsigned char digest[16], md5_context_t *context)
 
 	/* Zeroize sensitive information.
 	 */
-	memset((unsigned char *)context, 0, sizeof(*context));
+	memset((unsigned char *) context, 0, sizeof(*context));
 }
 
 void md5_buffer(const void *buffer, size_t length, unsigned char digest[16])
@@ -364,16 +311,16 @@ void md5_buffer(const void *buffer, size_t length, unsigned char digest[16])
 	md5_context_t context;
 
 	md5_init(&context);
-	md5_update(&context, (const unsigned char *)buffer, length);
+	md5_update(&context, (const unsigned char *) buffer, length);
 	md5_final(digest, &context);
 }
 
-#if defined(CCTOOLS_OPSYS_DARWIN) || defined(CCTOOLS_OPSYS_FREEBSD)
+#if defined(CCTOOLS_OPSYS_DARWIN)
 #define stat64 stat
 #endif
 
-#define BUFFER_SIZE (1 << 20)
-int md5_file(const char *filename, unsigned char digest[MD5_DIGEST_LENGTH])
+#define BUFFER_SIZE (1<<20)
+int md5_file(const char *filename, unsigned char digest[20])
 {
 	int fd;
 	struct stat buf;
@@ -410,25 +357,32 @@ int md5_file(const char *filename, unsigned char digest[MD5_DIGEST_LENGTH])
 	return 1;
 }
 
-const char *md5_to_string(unsigned char digest[16])
+const char *md5_string(unsigned char digest[16])
 {
 	static char str[33];
 	int i;
-	for (i = 0; i < 16; i++) {
-		sprintf(&str[i * 2], "%02x", (unsigned)digest[i]);
+	for(i = 0; i < 16; i++) {
+		sprintf(&str[i * 2], "%02x", (unsigned) digest[i]);
 	}
 	str[32] = 0;
 	return str;
 }
 
-char *md5_of_string(const char *s)
-{
+char *md5_cal(const char *s) {
 	unsigned char digest[MD5_DIGEST_LENGTH_HEX];
 	md5_context_t context;
+	char *p = NULL;
+
+	p = malloc(sizeof(char) * (MD5_DIGEST_LENGTH_HEX+1));
+	if(!p) {
+		return NULL;
+	}
+
 	md5_init(&context);
 	md5_update(&context, (const unsigned char *)s, strlen(s));
 	md5_final(digest, &context);
-	return strdup(md5_to_string(digest));
+	sprintf(p, "%s", md5_string(digest));
+	return p;
 }
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
