@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame This software is
+Copyright (C) 2013- The University of Notre Dame This software is
 distributed under the GNU General Public License.  See the file
 COPYING for details.
 */
@@ -28,11 +28,6 @@ struct rmsummary
 	char    *category;
 	char    *command;
 	char    *taskid;
-	
-	double cores;
-	double gpus;
-	double memory;
-	double disk;
 
 	char    *exit_type;
 	int64_t  signal;
@@ -42,14 +37,18 @@ struct rmsummary
 	double start;
 	double end;
 
+	double cores;
 	double cores_avg;
+	double gpus;
 
 	double wall_time;
 	double cpu_time;
 
+	double memory;
 	double virtual_memory;
 	double swap_memory;
 
+	double disk;
 	double bytes_read;
 	double bytes_written;
 
@@ -110,8 +109,6 @@ void rmsummary_merge_max_w_time(struct rmsummary *dest, const struct rmsummary *
 
 struct rmsummary *rmsummary_copy(const struct rmsummary *src, int deep_copy);
 void rmsummary_merge_override(struct rmsummary *dest, const struct rmsummary *src);
-void rmsummary_merge_override_basic(struct rmsummary *dest, const struct rmsummary *src);
-void rmsummary_merge_default(struct rmsummary *dest, const struct rmsummary *src);
 void rmsummary_merge_max(struct rmsummary *dest, const struct rmsummary *src);
 void rmsummary_merge_min(struct rmsummary *dest, const struct rmsummary *src);
 void rmsummary_add(struct rmsummary *dest, const struct rmsummary *src);
@@ -128,6 +125,6 @@ const char *rmsummary_resource_units(const char *resource_name);
 int rmsummary_resource_decimals(const char *resource_name);
 size_t rmsummary_resource_offset(const char *resource_name);
 
-const char *rmsummary_resource_to_str(const char *resource, double value, int include_units);
+const char *rmsummary_resource_to_str();
 
 #endif
