@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2013- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -13,8 +13,9 @@ See the file COPYING for details.
 #define DEFAULT_SIZE 127
 #define DEFAULT_LOAD 0.75
 
+
 struct entry {
-	uintptr_t element;
+	uintptr_t     element;
 	struct entry *next;
 };
 
@@ -30,16 +31,16 @@ struct set *set_create(int bucket_count)
 {
 	struct set *s;
 
-	s = (struct set *)malloc(sizeof(struct set));
-	if (!s)
+	s = (struct set *) malloc(sizeof(struct set));
+	if(!s)
 		return 0;
 
-	if (bucket_count == 0)
+	if(bucket_count == 0)
 		bucket_count = DEFAULT_SIZE;
 
 	s->bucket_count = bucket_count;
-	s->buckets = (struct entry **)calloc(bucket_count, sizeof(struct entry *));
-	if (!s->buckets) {
+	s->buckets = (struct entry **) calloc(bucket_count, sizeof(struct entry *));
+	if(!s->buckets) {
 		free(s);
 		return 0;
 	}
@@ -56,10 +57,11 @@ struct set *set_duplicate(struct set *s)
 	s2 = set_create(0);
 	set_first_element(s);
 	const void *element;
-	while ((element = set_next_element(s)))
+	while((element = set_next_element(s)))
 		set_insert(s2, element);
 
 	return s2;
+
 }
 
 struct set *set_union(struct set *s1, struct set *s2)
@@ -69,10 +71,11 @@ struct set *set_union(struct set *s1, struct set *s2)
 
 	set_first_element(s2);
 	const void *element;
-	while ((element = set_next_element(s2)))
+	while((element = set_next_element(s2)))
 		set_insert(s, element);
 
 	return s;
+
 }
 
 void set_clear(struct set *s)
@@ -80,16 +83,16 @@ void set_clear(struct set *s)
 	struct entry *e, *f;
 	int i;
 
-	for (i = 0; i < s->bucket_count; i++) {
+	for(i = 0; i < s->bucket_count; i++) {
 		e = s->buckets[i];
-		while (e) {
+		while(e) {
 			f = e->next;
 			free(e);
 			e = f;
 		}
 	}
 
-	for (i = 0; i < s->bucket_count; i++) {
+	for(i = 0; i < s->bucket_count; i++) {
 		s->buckets[i] = 0;
 	}
 }
@@ -111,13 +114,13 @@ int set_lookup(struct set *s, void *element)
 	struct entry *e;
 	uint64_t index;
 
-	uintptr_t key = (uintptr_t)element;
+	uintptr_t key = (uintptr_t) element;
 
 	index = key % s->bucket_count;
 	e = s->buckets[index];
 
-	while (e) {
-		if (key == e->element) {
+	while(e) {
+		if(key == e->element) {
 			return 1;
 		}
 		e = e->next;
@@ -130,14 +133,15 @@ static int set_double_buckets(struct set *s)
 {
 	struct set *sn = set_create(2 * s->bucket_count);
 
-	if (!sn)
+	if(!sn)
 		return 0;
 
 	/* Move elements to new set */
 	void *element;
 	set_first_element(s);
-	while ((element = set_next_element(s)))
-		if (!set_insert(sn, element)) {
+	while( (element = set_next_element(s)) )
+		if(!set_insert(sn, element))
+		{
 			set_delete(sn);
 			return 0;
 		}
@@ -145,9 +149,9 @@ static int set_double_buckets(struct set *s)
 	/* Delete all elements */
 	struct entry *e, *f;
 	int i;
-	for (i = 0; i < s->bucket_count; i++) {
+	for(i = 0; i < s->bucket_count; i++) {
 		e = s->buckets[i];
-		while (e) {
+		while(e) {
 			f = e->next;
 			free(e);
 			e = f;
@@ -156,9 +160,9 @@ static int set_double_buckets(struct set *s)
 
 	/* Make the old point to the new */
 	free(s->buckets);
-	s->buckets = sn->buckets;
+	s->buckets      = sn->buckets;
 	s->bucket_count = sn->bucket_count;
-	s->size = sn->size;
+	s->size         = sn->size;
 
 	/* Delete reference to new, so old is safe */
 	free(sn);
@@ -171,23 +175,23 @@ int set_insert(struct set *s, const void *element)
 	struct entry *e;
 	uint64_t index;
 
-	uintptr_t key = (uintptr_t)element;
+	uintptr_t key = (uintptr_t) element;
 
-	if (((float)s->size / s->bucket_count) > DEFAULT_LOAD)
+	if( ((float) s->size / s->bucket_count) > DEFAULT_LOAD )
 		set_double_buckets(s);
 
 	index = key % s->bucket_count;
 	e = s->buckets[index];
 
-	while (e) {
-		if (key == e->element) {
+	while(e) {
+		if(key == e->element) {
 			return 1;
 		}
 		e = e->next;
 	}
 
-	e = (struct entry *)malloc(sizeof(struct entry));
-	if (!e)
+	e = (struct entry *) malloc(sizeof(struct entry));
+	if(!e)
 		return 0;
 
 	e->element = key;
@@ -203,7 +207,7 @@ int set_insert_set(struct set *s, struct set *s2)
 	set_first_element(s2);
 	int additions = 0;
 	const void *element;
-	while ((element = set_next_element(s2))) {
+	while((element = set_next_element(s2))){
 		additions += set_insert(s, element);
 	}
 
@@ -215,7 +219,7 @@ int set_insert_list(struct set *s, struct list *l)
 	list_first_item(l);
 	int additions = 0;
 	const void *element;
-	while ((element = list_next_item(l))) {
+	while((element = list_next_item(l))){
 		additions += set_insert(s, element);
 	}
 
@@ -224,7 +228,7 @@ int set_insert_list(struct set *s, struct list *l)
 
 int set_push(struct set *s, const void *element)
 {
-	return set_insert(s, element);
+  return set_insert(s, element);
 }
 
 int set_remove(struct set *s, const void *element)
@@ -232,15 +236,15 @@ int set_remove(struct set *s, const void *element)
 	struct entry *e, *f;
 	uint64_t index;
 
-	uintptr_t key = (uintptr_t)element;
+	uintptr_t key = (uintptr_t) element;
 
 	index = key % s->bucket_count;
 	e = s->buckets[index];
 	f = 0;
 
-	while (e) {
-		if (key == e->element) {
-			if (f) {
+	while(e) {
+		if(key == e->element) {
+			if(f) {
 				f->next = e->next;
 			} else {
 				s->buckets[index] = e->next;
@@ -258,25 +262,25 @@ int set_remove(struct set *s, const void *element)
 
 void *set_pop(struct set *s)
 {
-	if (set_size(s) < 1)
-		return 0;
+  if( set_size(s) < 1 )
+	return 0;
 
-	void *element;
-	set_first_element(s);
-	element = set_next_element(s);
+  void *element;
+  set_first_element(s);
+  element = set_next_element(s);
 
-	if (!set_remove(s, element))
-		return 0;
-	else
-		return element;
+  if(!set_remove(s, element))
+	return 0;
+  else
+	return element;
 }
 
 void set_first_element(struct set *s)
 {
 	s->ientry = 0;
-	for (s->ibucket = 0; s->ibucket < s->bucket_count; s->ibucket++) {
+	for(s->ibucket = 0; s->ibucket < s->bucket_count; s->ibucket++) {
 		s->ientry = s->buckets[s->ibucket];
-		if (s->ientry)
+		if(s->ientry)
 			break;
 	}
 }
@@ -285,15 +289,15 @@ void *set_next_element(struct set *s)
 {
 	void *element;
 
-	if (s->ientry) {
-		element = (void *)s->ientry->element;
+	if(s->ientry) {
+		element = (void *) s->ientry->element;
 
 		s->ientry = s->ientry->next;
-		if (!s->ientry) {
+		if(!s->ientry) {
 			s->ibucket++;
-			for (; s->ibucket < s->bucket_count; s->ibucket++) {
+			for(; s->ibucket < s->bucket_count; s->ibucket++) {
 				s->ientry = s->buckets[s->ibucket];
-				if (s->ientry)
+				if(s->ientry)
 					break;
 			}
 		}
@@ -304,105 +308,4 @@ void *set_next_element(struct set *s)
 	}
 }
 
-void set_random_element(struct set *s, int *offset_bookkeep)
-{
-	s->ientry = 0;
-	if (s->bucket_count < 1) {
-		return;
-	}
-
-	int ibucket_start = random() % s->bucket_count;
-
-	for (s->ibucket = ibucket_start; s->ibucket < s->bucket_count; s->ibucket++) {
-		s->ientry = s->buckets[s->ibucket];
-		if (s->ientry) {
-			*offset_bookkeep = s->ibucket;
-			return;
-		}
-	}
-
-	for (s->ibucket = 0; s->ibucket < ibucket_start; s->ibucket++) {
-		s->ientry = s->buckets[s->ibucket];
-		if (s->ientry) {
-			*offset_bookkeep = s->ibucket;
-			return;
-		}
-	}
-}
-
-void *set_next_element_with_offset(struct set *s, int offset_bookkeep)
-{
-	if (s->bucket_count < 1) {
-		return 0;
-	}
-
-	void *element = NULL;
-
-	offset_bookkeep = offset_bookkeep % s->bucket_count;
-
-	if (s->ientry) {
-		element = (void *)s->ientry->element;
-
-		s->ientry = s->ientry->next;
-		if (!s->ientry) {
-			s->ibucket = (s->ibucket + 1) % s->bucket_count;
-			for (; s->ibucket != offset_bookkeep; s->ibucket = (s->ibucket + 1) % s->bucket_count) {
-				s->ientry = s->buckets[s->ibucket];
-				if (s->ientry) {
-					break;
-				}
-			}
-		}
-
-		return element;
-	}
-
-	return 0;
-}
-
-void **set_values(struct set *s)
-{
-	if (s->size < 1) {
-		return NULL;
-	}
-
-	void **elements = malloc(sizeof(void *) * s->size);
-
-	int offset_bookkeep;
-	void *element;
-	int i = 0;
-	SET_ITERATE_RANDOM_START(s, offset_bookkeep, element)
-	{
-		elements[i] = element;
-		i++;
-	}
-
-	return elements;
-}
-
-void **set_values_array(struct set *s)
-{
-	if (s->size < 1) {
-		return NULL;
-	}
-
-	void **elements = malloc(sizeof(void *) * (s->size + 1));
-	void *element;
-	int i = 0;
-	SET_ITERATE(s, element)
-	{
-		elements[i] = element;
-		i++;
-	}
-
-	elements[s->size] = NULL;
-
-	return elements;
-}
-
-void set_free_values_array(void **values)
-{
-	free(values);
-}
-
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
