@@ -4,18 +4,6 @@ export CC=${CC:-gcc}
 
 # Tests sometimes chdir, so we get the full path now. `pwd` is annoying to portable.
 WORK_QUEUE_WORKER=$(cd "$(dirname "$0")/../../work_queue/src/"; pwd)/work_queue_worker
-TASKVINE_WORKER=$(cd "$(dirname "$0")/../../taskvine/src/worker"; pwd)/vine_worker
-
-export GDB_WRAPPER="gdb --batch -ex run -ex bt -ex exit --args "
-
-# Obtain a config value from the master config file.
-
-import_config_val()
-{
-	name=$1
-	value=$(grep "^${name}=" ../../config.mk | cut -d = -f 2)
-	export ${name}=${value}
-}
 
 dispatch()
 {
@@ -42,32 +30,23 @@ dispatch()
 }
 
 # wait_for_file_creation(filename, timeout)
-# Waits at most timeout seconds for filename to be created.
+# Waits at most timeout seconds (default 5) for filename to be created.
 # Returns 0 if filename created before timeout, otherwise terminates the script.
-
 wait_for_file_creation()
 {
 	filename=$1
-	timeout=$2
+	timeout=${2:-5}
+	counter_seconds=0
 
-	if [ -z $filename ]
-	then
-		exit 1
-	fi
-	
-	for i in $(seq 1 $timeout)
+	[ -z $filename ] && exit 1
+
+	while [ $counter_seconds -lt $timeout ];
 	do
-		if [ -f $filename ]
-		then
-			return 0
-		else
-			echo "waiting for $filename ($i)..."
-			sleep 1
-		fi
+		[ -f $filename ] && return 0
+		counter_seconds=$(($counter_seconds + 1))
+		sleep 1
 	done
 
-	echo "$filename was not created after $timeout seconds!"
-	
 	exit 1
 }
 
@@ -97,13 +76,10 @@ wait_for_file_modification()
 	done
 }
 
-run_wq_worker()
+run_local_worker()
 {
 	local port_file=$1
-	shift
-	local log=$1
-	shift
-
+	local log=$2
 	local timeout=15
 
 	if [ -z "$log" ]; then
@@ -119,37 +95,7 @@ run_wq_worker()
 		exit 1
 	fi
 	echo "Running worker."
-	if ! "$WORK_QUEUE_WORKER" --single-shot --timeout=10s --cores ${cores:-1} --memory ${memory:-250} --disk ${disk:-250} --gpus ${gpus:-0} ${coprocess:-} --coprocess-cores ${coprocess_cores:-1} --coprocess-disk ${coprocess_disk:-250} --coprocess-memory ${coprocess_memory:-250} --coprocess-gpus ${coprocess_gpus:-0} --debug=all --debug-file="$log" $* localhost $(cat "$port_file"); then
-		echo "ERROR: could not start worker"
-		exit 1
-	fi
-	echo "Worker completed."
-	return 0
-}
-
-run_taskvine_worker()
-{
-	local port_file=$1
-	shift
-	local log=$1
-	shift
-
-	local timeout=15
-
-	if [ -z "$log" ]; then
-		log=worker.log
-	fi
-
-	echo "Waiting for manager to be ready."
-	if wait_for_file_creation $port_file $timeout
-	then
-		echo "Master is ready on port `cat $port_file` "
-	else
-		echo "ERROR: Master failed to respond in $timeout seconds."
-		exit 1
-	fi
-	echo "Running worker."
-	if ! "$TASKVINE_WORKER" --single-shot --timeout=10 --cores ${cores:-1} --memory ${memory:-250} --disk ${disk:-250} --gpus ${gpus:-0} --debug=all --debug-file="$log" $* localhost $(cat "$port_file"); then
+	if ! "$WORK_QUEUE_WORKER" --single-shot --timeout=10s --cores ${cores:-1} --memory ${memory:-250} --disk ${disk:-250} --gpus ${gpus:-0} --debug=all --debug-file="$log" localhost $(cat "$port_file"); then
 		echo "ERROR: could not start worker"
 		exit 1
 	fi
@@ -177,13 +123,6 @@ check_needed()
 	return 0
 }
 
-latest_vine_debug_log()
-{
-	base=${1:-vine-run-info}
-	echo "${base}/most-recent/vine-logs/debug"
-}
-
-
 # For OS X
 if ! echo $PATH | grep /sbin > /dev/null 2>&1; then
 	export PATH=$PATH:/usr/sbin:/sbin
