@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2014- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -15,7 +15,7 @@ See the file COPYING for details.
 #include "string_set.h"
 #include "set.h"
 #include "timestamp.h"
-#include "batch_queue.h"
+#include "batch_job.h"
 #include "category.h"
 
 #include <stdio.h>
