@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2014- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -9,7 +9,7 @@ See the file COPYING for details.
 #include "dag_node.h"
 
 #include "debug.h"
-#include "batch_job.h"
+#include "batch_task.h"
 #include "rmsummary.h"
 #include "list.h"
 #include "stringtools.h"
@@ -421,7 +421,7 @@ struct jx * dag_node_env_create( struct dag *d, struct dag_node *n, int should_s
 /* Return resources according to request. */
 
 const struct rmsummary *dag_node_dynamic_label(const struct dag_node *n) {
-	return category_task_max_resources(n->category, n->resources_requested, n->resource_request, -1);
+	return category_dynamic_task_max_resources(n->category, n->resources_requested, n->resource_request);
 }
 
 /* Return JX object containing cmd, inputs, outputs, env, and resources. */
