@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2013- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -692,6 +692,8 @@ void dag_to_dot(struct dag *d, int condense_display, int change_size, int with_l
 	char *label;
 
 	//Dot Details Variables
+	int i;
+	int j;
 	struct file_node *src;
 	struct file_node *tar;
 
@@ -796,10 +798,12 @@ void dag_to_dot(struct dag *d, int condense_display, int change_size, int with_l
 
 				//Source Files
 				list_first_item(n->source_files);
+				i = 0;
 				while((f = list_next_item(n->source_files))) {
 					fn = f->filename;
 					e = hash_table_lookup(g, fn);
 					if(e) {
+						i++;
 						printf("\tsrc_%d_%d [label=\"%s\", style=unfilled, color=purple, shape=box];\n", condense_display ? t->id : n->nodeid, e->id, e->name);
 						printf("\tsrc_%d_%d -> N%d;\n", condense_display ? t->id : n->nodeid, e->id, condense_display ? t->id : n->nodeid);
 					}
@@ -807,10 +811,12 @@ void dag_to_dot(struct dag *d, int condense_display, int change_size, int with_l
 
 				//Target Files
 				list_first_item(n->target_files);
+				j = 0;
 				while((f = list_next_item(n->target_files))) {
 					fn = f->filename;
 					e = hash_table_lookup(g, fn);
 					if(e) {
+						j++;
 						printf("\ttar_%d_%d [label=\"%s\", style=dotted, color=purple, shape=box];\n", condense_display ? t->id : n->nodeid, e->id, e->name);
 						printf("\tN%d -> tar_%d_%d;\n", condense_display ? t->id : n->nodeid, condense_display ? t->id : n->nodeid, e->id);
 
@@ -916,10 +922,19 @@ void dag_to_dot(struct dag *d, int condense_display, int change_size, int with_l
 
 	printf( "}\n");
 
+	hash_table_firstkey(h);
+	while(hash_table_nextkey(h, &label, (void **) &t)) {
+		free(t);
+		hash_table_remove(h, label);
+	}
+
+	hash_table_firstkey(g);
+	while(hash_table_nextkey(g, &label, (void **) &e)) {
+		free(e);
+		hash_table_remove(g, label);
+	}
 
-	hash_table_clear(g, free);
 	hash_table_delete(g);
-	hash_table_clear(h, free);
 	hash_table_delete(h);
 }
 
@@ -1169,12 +1184,6 @@ struct jx *category_allocation_to_json(category_allocation_t c) {
 		case CATEGORY_ALLOCATION_ERROR:
 			return jx_string("error");
 			break;
-		case CATEGORY_ALLOCATION_GREEDY_BUCKETING:
-			return jx_string("greedy bucketing");
-			break;
-		case CATEGORY_ALLOCATION_EXHAUSTIVE_BUCKETING:
-			return jx_string("exhaustive bucketing");
-			break;
 	}
 	return jx_null();
 }
