@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2016- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -10,8 +10,10 @@ See the file COPYING for details.
 #include "list.h"
 #include "makeflow_summary.h"
 #include "catalog_query.h"
+#include "json.h"
+#include "json_aux.h"
 #include "username.h"
-#include "batch_queue.h"
+#include "batch_job.h"
 #include "jx_print.h"
 
 #include <stdlib.h>
@@ -77,7 +79,7 @@ int	makeflow_catalog_summary (struct dag *d, char *name, batch_queue_type_t type
   	//creates memory
   	char *text = jx_print_string (j);
 
-  	int resp = catalog_query_send_update(host,text,CATALOG_UPDATE_BACKGROUND);
+  	int resp = catalog_query_send_update (host, text);
 
   	free (text);
   	free (timestring);
