@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2008- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -29,7 +29,7 @@ See the file COPYING for details.
 #include "hash_table.h"
 #include "itable.h"
 #include "debug.h"
-#include "unlink_recursive.h"
+#include "delete_dir.h"
 #include "stringtools.h"
 #include "load_average.h"
 #include "get_line.h"
