@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2008- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -30,7 +30,7 @@ See the file COPYING for details.
 #include "hash_table.h"
 #include "itable.h"
 #include "debug.h"
-#include "unlink_recursive.h"
+#include "delete_dir.h"
 #include "stringtools.h"
 #include "load_average.h"
 #include "get_line.h"
@@ -96,6 +96,7 @@ struct dag *dag_from_file(const char *filename, dag_syntax_type format, struct j
 		case DAG_SYNTAX_JX: //Evaluates the pending JX Variables from args file
 			jx_tmp = jx_eval_with_defines(dag,args);
 			jx_delete(dag);
+			jx_delete(args);
 			dag = jx_tmp;
 			 //Intentional fall-through as JX and JSON both use dag_parse_jx
 			/* falls through */
@@ -216,6 +217,9 @@ void set_resources_from_env(struct rmsummary *rs, struct dag_variable_lookup_set
             debug(D_NOTICE, "%s defined multiple times for category %s. Using last defined value: %s",
                     RESOURCES_WALL_TIME, c->name, rmsummary_resource_to_str("wall_time", rs->wall_time, 0));
         }
+
+        /* value in RESOURCES_WALL_TIME is in seconds. struct rmsummary expects it in useconds. */
+		rs->wall_time *= 1000000;
 	}
 }
 
