@@ -50,7 +50,8 @@ run()
 
 clean()
 {
-	rm -f $MAKE_FILE $STATUS_FILE $PORT_FILE $WORKER_LOG out.1 out.2 out.actual out.expected
+	../src/makeflow -c $MAKE_FILE
+	rm -f $MAKE_FILE $STATUS_FILE $PORT_FILE $WORKER_LOG out.1 out.2 out.actual out.expected input.txt
 }
 
 dispatch "$@"
