@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2005- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -34,7 +34,7 @@ extern "C" {
 #include "chirp_ticket.h"
 #include "create_dir.h"
 #include "debug.h"
-#include "unlink_recursive.h"
+#include "delete_dir.h"
 #include "file_cache.h"
 #include "ftp_lite.h"
 #include "getopt.h"
@@ -612,7 +612,7 @@ int main( int argc, char *argv[] )
 	debug_config(argv[0]);
 	debug_config_file_size(0); /* do not rotate debug file by default */
 	debug_config_fatal(pfs_process_killall);
-	debug_config_child_getpid(pfs_process_getpid);
+	debug_config_getpid(pfs_process_getpid);
 
 	/* Special file descriptors (currently the channel and the Parrot
 	 * directory) are allocated from the top of our file descriptor pool. After
@@ -1210,8 +1210,8 @@ int main( int argc, char *argv[] )
 		for (int i = 0; environ[i]; i++)
 			fprintf(fp, "%s%c", environ[i], '\0');
 		char working_dir[PATH_MAX];
-		char *r = ::getcwd(working_dir,sizeof(working_dir));
-		if(!r)
+		::getcwd(working_dir,sizeof(working_dir));
+		if(working_dir == NULL)
 			fatal("Can not obtain the current working directory!");
 		fprintf(fp, "PWD=%s\n", working_dir);
 		fclose(fp);
@@ -1456,7 +1456,7 @@ int main( int argc, char *argv[] )
 
 	if(pfs_paranoid_mode) pfs_paranoia_cleanup();
 
-	unlink_recursive(pfs_temp_per_instance_dir);
+	delete_dir(pfs_temp_per_instance_dir);
 
 	if(namelist_table && namelist_file) {
 		char *key;
@@ -1492,4 +1492,4 @@ int main( int argc, char *argv[] )
 	}
 }
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
