@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2005- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -417,21 +417,6 @@ RETRY:
 		}
 		END
 	}
-#ifdef HAS_STATX
-	virtual int statx( pfs_name *name, int flags, unsigned int mask, struct pfs_statx *buf ) {
-		stats_inc("parrot.local.statx", 1);
-		int result;
-		struct statx lbuf;
-		memset(&lbuf,0,sizeof(lbuf));
-		if(!pfs_acl_check(name,IBOX_ACL_LIST)) return -1;
-		debug(D_LOCAL,"statx %s %p",name->rest,buf);
-		result = ::statx(AT_FDCWD,name->rest,flags,mask,&lbuf);
-		if(result>=0){
-				COPY_STATX(lbuf,*buf);
-		}
-		END
-	}
-#endif
 	virtual int access( pfs_name *name, mode_t mode ) {
 		stats_inc("parrot.local.access", 1);
 		int result;
@@ -784,4 +769,4 @@ struct pfs_file * pfs_file_bootstrap( int fd, const char *path )
 	return new pfs_file_local(&name,fd);
 }
 
-/* vim: set noexpandtab tabstop=8: */
+/* vim: set noexpandtab tabstop=4: */
