@@ -3,8 +3,7 @@ import resource_monitor
 import sys
 import time
 
-
-@resource_monitor.monitored(limits={"wall_time": 1})  # wall_time in seconds
+@resource_monitor.monitored(limits = {'wall_time': 1})  # wall_time in seconds
 def my_function(n):
     sys.stdout.write("waiting for {time} seconds...".format(time=n))
     time.sleep(n)
@@ -12,13 +11,10 @@ def my_function(n):
 
     return n
 
-
 try:
     (output, resources) = my_function(0.5)
 except Exception as e:
-    sys.stdout.write(
-        "\nGot exception <{err}>, but did not expect any error.\n".format(err=e)
-    )
+    sys.stdout.write("\nGot exception <{err}>, but did not expect any error.\n".format(err=e))
     sys.exit(1)
 
 
@@ -27,9 +23,8 @@ try:
 except resource_monitor.ResourceExhaustion as e:
     sys.stdout.write("\nGot expected exception <{err}>.\n".format(err=e))
 except Exception as e:
-    sys.stdout.write(
-        "\nGot exception <{err}>, but did not expect such error.\n".format(err=e)
-    )
+    sys.stdout.write("\nGot exception <{err}>, but did not expect such error.\n".format(err=e))
     sys.exit(1)
 
 sys.exit(0)
+
