@@ -1,24 +1,24 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2013- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
 
 #include <stdio.h>
+#include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
+#include <sys/socket.h>
+#include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
-#include <netinet/in.h>
-#include <sys/socket.h>
 
 #include <errno.h>
 #include <fcntl.h>
-#include <limits.h>
-#include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <limits.h>
 
 #include "stringtools.h"
 #include "xxmalloc.h"
@@ -26,51 +26,53 @@ See the file COPYING for details.
 #include "rmonitor_helper_comm.h"
 
 #include "debug.h"
-// #define debug fprintf
-// #define D_RMON stderr
+//#define debug fprintf
+//#define D_RMON stderr
+
 
 const char *str_msgtype(enum rmonitor_msg_type n)
 {
-	switch (n) {
-	case BRANCH:
-		return "branch";
-		break;
-	case END:
-		return "end";
-		break;
-	case END_WAIT:
-		return "end_wait";
-		break;
-	case WAIT:
-		return "wait";
-		break;
-	case CHDIR:
-		return "chdir";
-		break;
-	case OPEN_INPUT:
-		return "open-input-file";
-		break;
-	case OPEN_OUTPUT:
-		return "open-output-file";
-		break;
-	case READ:
-		return "read";
-		break;
-	case WRITE:
-		return "write";
-		break;
-	case RX:
-		return "received";
-		break;
-	case TX:
-		return "sent";
-		break;
-	case SNAPSHOT:
-		return "snapshot";
-		break;
-	default:
-		return "unknown";
-		break;
+	switch(n)
+	{
+		case BRANCH:
+			return "branch";
+			break;
+		case END:
+			return "end";
+			break;
+		case END_WAIT:
+			return "end_wait";
+			break;
+		case WAIT:
+			return "wait";
+			break;
+		case CHDIR:
+			return "chdir";
+			break;
+		case OPEN_INPUT:
+			return "open-input-file";
+			break;
+		case OPEN_OUTPUT:
+			return "open-output-file";
+			break;
+		case READ:
+			return "read";
+			break;
+		case WRITE:
+			return "write";
+			break;
+		case RX:
+			return "received";
+			break;
+		case TX:
+			return "sent";
+			break;
+		case SNAPSHOT:
+			return "snapshot";
+			break;
+		default:
+			return "unknown";
+			break;
 	};
 }
 
@@ -78,25 +80,27 @@ char *rmonitor_helper_locate(char *default_path)
 {
 	char *helper_path;
 
-	debug(D_RMON, "locating helper library...\n");
+	debug(D_RMON,"locating helper library...\n");
 
-	debug(D_RMON, "trying library from $%s.\n", RESOURCE_MONITOR_HELPER_ENV_VAR);
+	debug(D_RMON,"trying library from $%s.\n", RESOURCE_MONITOR_HELPER_ENV_VAR);
 	helper_path = getenv(RESOURCE_MONITOR_HELPER_ENV_VAR);
-	if (helper_path) {
-		if (access(helper_path, R_OK | X_OK) == 0)
+	if(helper_path)
+	{
+		if(access(helper_path, R_OK|X_OK) == 0)
 			return xxstrdup(helper_path);
 	}
 
-	if (default_path) {
-		debug(D_RMON, "trying library at default path...\n");
-		if (access(default_path, R_OK | X_OK) == 0)
+	if(default_path)
+	{
+		debug(D_RMON,"trying library at default path...\n");
+		if(access(default_path, R_OK|X_OK) == 0)
 			return xxstrdup(default_path);
 	}
 
-	debug(D_RMON, "trying library at default location.\n");
+	debug(D_RMON,"trying library at default location.\n");
 	free(helper_path);
 	helper_path = string_format("%s/lib/librmonitor_helper.so", INSTALL_PATH);
-	if (access(helper_path, R_OK | X_OK) == 0)
+	if(access(helper_path, R_OK|X_OK) == 0)
 		return helper_path;
 
 	return NULL;
@@ -116,13 +120,13 @@ int find_localhost_addr(int port, struct addrinfo **addr)
 
 	memset(&info, 0, sizeof(info));
 
-	info.ai_family = AF_INET;
-	info.ai_socktype = SOCK_DGRAM;
-	info.ai_protocol = 0;
-	info.ai_flags = AI_ADDRCONFIG;
+	info.ai_family=AF_INET;
+	info.ai_socktype=SOCK_DGRAM;
+	info.ai_protocol=0;
+	info.ai_flags=AI_ADDRCONFIG;
 
 	int status = getaddrinfo(hostname, portname, &info, &res);
-	if (status != 0)
+	if( status != 0)
 		debug(D_RMON, "couldn't resolve socket address: %s\n", strerror(errno));
 
 	free(portname);
@@ -146,44 +150,47 @@ int rmonitor_server_open_socket(int *fd, int *port)
 	if (highstr)
 		high = atoi(highstr);
 
-	if (high < low) {
+	if(high < low)
+	{
 		debug(D_RMON, "high port %d is less than low port %d in range", high, low);
 		return 0;
 	}
 
 	*fd = socket(AF_INET, SOCK_DGRAM, 0);
-	if (*fd < 0) {
-		debug(D_RMON, "couldn't open socket for reading.");
+	if(*fd < 0)
+	{
+		debug(D_RMON,"couldn't open socket for reading.");
 		return 0;
 	}
 
-	for (*port = low; *port <= high; *port += 1) {
+	for(*port = low; *port <= high; *port +=1) {
 		int status = find_localhost_addr(*port, &addr);
 
-		if (!bind(*fd, addr->ai_addr, addr->ai_addrlen)) {
+		if(!bind(*fd, addr->ai_addr, addr->ai_addrlen))
+		{
 			free(addr);
-			debug(D_RMON, "socket open at port %d\n", *port);
+			debug(D_RMON,"socket open at port %d\n", *port);
 			return *port;
 		}
 
-		if (status == 0)
+		if(status == 0)
 			free(addr);
 	}
 
-	debug(D_RMON, "couldn't find open port for socket.");
+	debug(D_RMON,"couldn't find open port for socket.");
 
 	return 0;
 }
 
-int rmonitor_client_open_socket(int *fd, struct addrinfo **addr)
-{
+int rmonitor_client_open_socket(int *fd, struct addrinfo **addr) {
 	int port;
 	char *socket_info;
 	struct addrinfo *res;
 
 	socket_info = getenv(RESOURCE_MONITOR_INFO_ENV_VAR);
-	if (!socket_info) {
-		debug(D_RMON, "couldn't find socket info.\n");
+	if(!socket_info)
+	{
+		debug(D_RMON,"couldn't find socket info.\n");
 		return -1;
 	}
 
@@ -192,54 +199,61 @@ int rmonitor_client_open_socket(int *fd, struct addrinfo **addr)
 
 	int status = find_localhost_addr(port, &res);
 
-	if (status != 0) {
-		debug(D_RMON, "couldn't read socket information.");
+	if(status != 0) {
+		debug(D_RMON,"couldn't read socket information.");
 		return -1;
 	}
 
+
 	*fd = socket(res->ai_family, res->ai_socktype, res->ai_protocol);
-	if (*fd < 0) {
-		debug(D_RMON, "couldn't open socket for writing.");
+	if(*fd < 0)
+	{
+		debug(D_RMON,"couldn't open socket for writing.");
 		freeaddrinfo(res);
 		return -1;
 	}
 
-	struct timeval read_timeout = {.tv_sec = 10, .tv_usec = 0};
-	setsockopt(*fd, SOL_SOCKET, SO_RCVTIMEO, (const void *)&read_timeout, sizeof(read_timeout));
+	struct timeval read_timeout = { .tv_sec = 10, .tv_usec = 0 };
+	setsockopt(*fd, SOL_SOCKET, SO_RCVTIMEO, (const void *) &read_timeout, sizeof(read_timeout));
 
 	*addr = res;
 
 	return 0;
 }
 
-/* We use datagrams to send information to the monitor from the
- * great grandchildren processes */
+ /* We use datagrams to send information to the monitor from the
+  * great grandchildren processes */
 int rmonitor_helper_init(char *lib_default_path, int *fd, int stop_short_running)
 {
-	int port;
+	int  port;
 	char *helper_path = rmonitor_helper_locate(lib_default_path);
 	char helper_absolute[PATH_MAX + 1];
 	char *rmonitor_port;
 
 	realpath(helper_path, helper_absolute);
 
-	if (access(helper_absolute, R_OK | X_OK) == 0) {
+	if(access(helper_absolute,R_OK|X_OK)==0) {
 		debug(D_RMON, "found helper in %s\n", helper_absolute);
 		rmonitor_server_open_socket(fd, &port);
-	} else {
-		debug(D_RMON, "couldn't find helper library %s but continuing anyway.", helper_path);
+	}
+	else {
+		debug(D_RMON,"couldn't find helper library %s but continuing anyway.", helper_path);
 		port = -1;
 	}
 
-	if (port > 0) {
+	if(port > 0)
+	{
 		rmonitor_port = string_format("%d", port);
 
 		char *prev_ldpreload = getenv("LD_PRELOAD");
-		char *ld_preload = string_format("%s%s%s", helper_absolute, prev_ldpreload ? ":" : "", prev_ldpreload ? prev_ldpreload : "");
+		char *ld_preload     = string_format("%s%s%s",
+				helper_absolute,
+				prev_ldpreload ? ":" : "",
+				prev_ldpreload ? prev_ldpreload : "");
 
-		debug(D_RMON, "setting LD_PRELOAD to %s\n", ld_preload);
+		debug(D_RMON,"setting LD_PRELOAD to %s\n", ld_preload);
 
-		if (stop_short_running) {
+		if(stop_short_running) {
 			setenv(RESOURCE_MONITOR_HELPER_STOP_SHORT, "1", 1);
 		}
 
@@ -251,12 +265,14 @@ int rmonitor_helper_init(char *lib_default_path, int *fd, int stop_short_running
 
 		setenv("LD_PRELOAD", ld_preload, 1);
 
-		debug(D_RMON, "setting %s to %s\n", RESOURCE_MONITOR_INFO_ENV_VAR, rmonitor_port);
+		debug(D_RMON,"setting %s to %s\n", RESOURCE_MONITOR_INFO_ENV_VAR, rmonitor_port);
 		setenv(RESOURCE_MONITOR_INFO_ENV_VAR, rmonitor_port, 1);
 
 		free(ld_preload);
 		free(rmonitor_port);
-	} else {
+	}
+	else
+	{
 		*fd = -1;
 	}
 
@@ -269,9 +285,9 @@ int send_monitor_msg(struct rmonitor_msg *msg)
 	static int fd = -1;
 	static struct addrinfo *addr = NULL;
 
-	if (fd < 0) {
+	if(fd < 0) {
 		int status = rmonitor_client_open_socket(&fd, &addr);
-		if (status < 0) {
+		if(status < 0) {
 			return status;
 		}
 	}
@@ -282,4 +298,6 @@ int send_monitor_msg(struct rmonitor_msg *msg)
 	return count;
 }
 
+
+
 /* vim: set noexpandtab tabstop=4: */
