@@ -1,24 +1,24 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2015- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
 
 #include <stdio.h>
-#include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <string.h>
 
 #include "rmonitor_poll.h"
 #include "rmsummary.h"
 
-int main(int argc, char **argv)
-{
+int main(int argc, char **argv) {
 	sleep(2);
 
-	struct rmsummary *resources = rmonitor_measure_process(getpid(), /* include disk */ 1);
+	struct rmsummary *resources = rmonitor_measure_process(getpid());
 
-	fprintf(stdout, "command: %s, ", resources->command);
+	fprintf(stdout, "command: %s, ",
+			resources->command);
 
 	fprintf(stdout, "wall time used (s): %3.0f, ", resources->wall_time);
 
