@@ -259,6 +259,15 @@ sub specify_running_time {
 	return work_queue_task_specify_running_time($self->{_task}, $useconds);
 }
 
+sub specify_running_time_max {
+	my ($self, $seconds) = @_;
+	return work_queue_task_specify_running_time_max($self->{_task}, $seconds);
+}
+
+sub specify_running_time_min {
+	my ($self, $seconds) = @_;
+	return work_queue_task_specify_running_time_min($self->{_task}, $seconds);
+}
 sub specify_priority {
 	my ($self, $priority) = @_;
 	return work_queue_task_specify_priority($self->{_task}, $priority);
@@ -315,6 +324,11 @@ sub result {
 	return $self->{_task}->{result};
 }
 
+sub result_str {
+	my ($self) = @_;
+	return work_queuec::work_queue_result_str($self->{_task}->{result});
+}
+
 sub total_submissions {
 	my ($self) = @_;
 	return $self->{_task}->{total_submissions};
@@ -932,8 +946,11 @@ Number of microseconds.
 
 =head3 C<specify_running_time>
 
-Indicate the maximum running time for a task in a worker (relative to when the
-task starts to run).  If less than 1, or not specified, no limit is imposed.
+Indicate the maximum running time (in microseconds) for a task in a worker
+(relative to when the task starts to run).  If less than 1, or not specified,
+no limit is imposed.
+Note: Same as specify_running_time_max, but specified in microseconds. Kept for
+backwards compatibility.
 
 =over 12
 
@@ -943,6 +960,33 @@ Number of microseconds.
 
 =back
 
+=head3 C<specify_running_time_max>
+
+Indicate the maximum running time (in seconds) for a task in a worker (relative to when the
+task starts to run).  If less than 1, or not specified, no limit is imposed.
+
+=over 12
+
+=item seconds
+
+Number of seconds.
+
+=back
+
+
+=head3 C<specify_running_time_min>
+
+Indicate the minimum running time (in seconds) the task needs (relative to when the
+task starts to run).  If less than 1, or not specified, no minimum time is defined.
+
+=over 12
+
+=item seconds
+
+Number of seconds.
+
+=back
+
 =head3 C<specify_priority>
 
 Indicate the the priority of this task (larger means better priority,
@@ -1017,10 +1061,14 @@ after the task completes execution.
 
 =head3 C<result>
 
-Get the result of the task (successful, failed return_status, missing input file, missing output file).
+Get the result of the task as in integer (successful, failed return_status, missing input file, missing output file).
 
 Must be called only after the task completes execution.
 
+=head3 C<result_str>
+
+Returns a string that explains the result of a task. (SUCCESS, INPUT_MISS, OUTPUT_MISS, etc.)
+
 =head3 C<total_submissions>
 
 Get the number of times the task has been resubmitted internally.
