@@ -3,23 +3,17 @@
 #include "work_queue.h"
 #include "work_queue_internal.h"
 #include "work_queue_gpus.h"
-#include "work_queue_protocol.h"
-#include "work_queue_coprocess.h"
 
 #include "debug.h"
 #include "errno.h"
 #include "macros.h"
 #include "stringtools.h"
 #include "create_dir.h"
+#include "delete_dir.h"
 #include "list.h"
 #include "disk_alloc.h"
 #include "path.h"
 #include "xxmalloc.h"
-#include "trash.h"
-#include "link.h"
-#include "timestamp.h"
-#include "domain_name.h"
-#include "full_io.h"
 
 #include <math.h>
 #include <stdio.h>
@@ -36,39 +30,20 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 
-/*
-Create the task sandbox directory.  If disk allocation is enabled,
-make an allocation, otherwise just make a directory.
-Create temporary directories inside as well.
-*/
+// return 0 on error, 1 otherwise
+static int create_task_directories(struct work_queue_process *p) {
+	char tmpdir_template[1024];
 
-extern char * workspace;
-
-static int create_sandbox_dir( struct work_queue_process *p, int disk_allocation )
-{
-	p->cache_dir = string_format("%s/cache",workspace);
-  	p->sandbox = string_format("%s/t.%d", workspace,p->task->taskid);
-
-	if(disk_allocation) {
-		work_queue_process_compute_disk_needed(p);
-		if(p->task->resources_requested->disk > 0) {
-			int64_t size = (p->task->resources_requested->disk) * 1024;
-			if(disk_alloc_create(p->sandbox, "ext2", size) == 0) {
-				p->loop_mount = 1;
-				debug(D_WQ, "allocated %"PRId64"MB in %s\n",size,p->sandbox);
-				// keep going and fall through
-			} else {
-				debug(D_WQ, "couldn't allocate %"PRId64"MB in %s\n",size,p->sandbox);
-				return 0;
-			}
-		} else {
-			if(!create_dir(p->sandbox, 0777)) return 0;
-		}
-	} else {
-		if(!create_dir(p->sandbox, 0777)) return 0;
+	p->sandbox = string_format("t.%d", p->task->taskid);
+	if(!create_dir(p->sandbox, 0777)) {
+		return 0;
 	}
 
-	char tmpdir_template[1024];
+	char absolute[1024];
+	path_absolute(p->sandbox, absolute, 1);
+	free(p->sandbox);
+	p->sandbox = xxstrdup(absolute);
+
 	string_nformat(tmpdir_template, sizeof(tmpdir_template), "%s/cctools-temp-t.%d.XXXXXX", p->sandbox, p->task->taskid);
 	if(mkdtemp(tmpdir_template) == NULL) {
 		return 0;
@@ -82,30 +57,49 @@ static int create_sandbox_dir( struct work_queue_process *p, int disk_allocation
 	return 1;
 }
 
-/*
-Create a work_queue_process and all of the information necessary for invocation.
-However, do not allocate substantial resources at this point.
-*/
-
 struct work_queue_process *work_queue_process_create(struct work_queue_task *wq_task, int disk_allocation)
 {
 	struct work_queue_process *p = malloc(sizeof(*p));
 	memset(p, 0, sizeof(*p));
 	p->task = wq_task;
 	p->task->disk_allocation_exhausted = 0;
-	p->coprocess = NULL;
+	//placeholder filesystem until permanent solution
+	char *fs = "ext2";
 
+	if(disk_allocation == 1) {
+		work_queue_process_compute_disk_needed(p);
+		if(p->task->resources_requested->disk > 0) {
+			int64_t size = (p->task->resources_requested->disk) * 1024;
+			p->sandbox = string_format("t.%d", p->task->taskid);
 
-	if(!create_sandbox_dir(p,disk_allocation)) {
-		work_queue_process_delete(p);
-		return 0;
+			if(disk_alloc_create(p->sandbox, fs, size) == 0) {
+				p->loop_mount = 1;
+				debug(D_WQ, "disk_alloc: %"PRId64"MB\n", size);
+				return p;
+			}
+		}
+		if(!create_task_directories(p)) {
+			work_queue_process_delete(p);
+			return 0;
+		}
+
+		p->loop_mount = 0;
+		return p;
 	}
-	return p;
-}
+	else {
+		if(!create_task_directories(p)) {
+			work_queue_process_delete(p);
+			return 0;
+		}
 
+		p->loop_mount = 0;
+		return p;
+	}
+}
 
 void work_queue_process_delete(struct work_queue_process *p)
 {
+
 	if(p->task)
 		work_queue_task_delete(p->task);
 
@@ -114,15 +108,16 @@ void work_queue_process_delete(struct work_queue_process *p)
 	}
 
 	if(p->output_file_name) {
-		trash_file(p->output_file_name);
+		unlink(p->output_file_name);
 		free(p->output_file_name);
 	}
 
 	if(p->sandbox) {
 		if(p->loop_mount == 1) {
 			disk_alloc_delete(p->sandbox);
-		} else {
-			trash_file(p->sandbox);
+		}
+		else {
+			delete_dir(p->sandbox);
 		}
 		free(p->sandbox);
 	}
@@ -130,9 +125,6 @@ void work_queue_process_delete(struct work_queue_process *p)
 	if(p->tmpdir)
 		free(p->tmpdir);
 
-	if(p->cache_dir)
-		free(p->cache_dir);
-	
 	free(p);
 }
 
@@ -203,26 +195,6 @@ static void specify_resources_vars(struct work_queue_process *p) {
 
 static const char task_output_template[] = "./worker.stdout.XXXXXX";
 
-static char * load_input_file(struct work_queue_task *t) {
-	FILE *fp = fopen("infile", "r");
-	if(!fp) {
-		fatal("coprocess could not open file 'infile' for reading: %s", strerror(errno));
-	}
-
-	fseek(fp, 0L, SEEK_END);
-	size_t fsize = ftell(fp);
-	fseek(fp, 0L, SEEK_SET);
-	// using calloc solves problem of garbage appended to buffer
-	char *buf = calloc(fsize + 1, sizeof(*buf));
-
-	int bytes_read = full_fread(fp, buf, fsize);
-	if(bytes_read < 0) {
-		fatal("error reading file: %s", strerror(errno));
-	}
-
-	return buf;
-}
-
 pid_t work_queue_process_execute(struct work_queue_process *p )
 {
 	// make warning
@@ -277,28 +249,13 @@ pid_t work_queue_process_execute(struct work_queue_process *p )
 		if(result == -1)
 			fatal("could not dup /dev/null to stdin: %s", strerror(errno));
 
-		if (p->coprocess == NULL) {
-			result = dup2(p->output_fd, STDOUT_FILENO);
-			if(result == -1)
-				fatal("could not dup pipe to stdout: %s", strerror(errno));
+		result = dup2(p->output_fd, STDOUT_FILENO);
+		if(result == -1)
+			fatal("could not dup pipe to stdout: %s", strerror(errno));
 
-			result = dup2(p->output_fd, STDERR_FILENO);
-			if(result == -1)
-				fatal("could not dup pipe to stderr: %s", strerror(errno));
-			}
-		else {
-			// load data from input file
-			char *input = load_input_file(p->task);
-
-			// call invoke_coprocess_function
-		 	char *output = work_queue_coprocess_run(p->task->command_line, input, p->coprocess, p->task->taskid);
-			// write data to output file
-			if(output) {
-				full_write(p->output_fd, output, strlen(output));
-			}
-			
-			exit(0);
-		}
+		result = dup2(p->output_fd, STDERR_FILENO);
+		if(result == -1)
+			fatal("could not dup pipe to stderr: %s", strerror(errno));
 
 		close(p->output_fd);
 
@@ -377,7 +334,7 @@ int work_queue_process_measure_disk(struct work_queue_process *p, int max_time_o
 
 	struct path_disk_size_info *state = p->disk_measurement_state;
 
-	int result = path_disk_size_info_get_r(p->sandbox, max_time_on_measurement, &state, NULL);
+	int result = path_disk_size_info_get_r(p->sandbox, max_time_on_measurement, &state);
 
 	/* not a memory leak... Either disk_measurement_state was NULL or the same as state. */
 	p->disk_measurement_state = state;
