@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2013- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -55,7 +55,7 @@ void work_queue_resources_measure_locally( struct work_queue_resources *r, const
 
 	if(!gpu_check)
 	{
-		r->gpus.total = gpu_count_get();
+		r->gpus.total = gpu_info_get();
 		r->gpus.largest = r->gpus.smallest = r->gpus.total;
 		gpu_check = 1;
 	}
@@ -73,7 +73,7 @@ static void work_queue_resource_debug( struct work_queue_resource *r, const char
 static void work_queue_resource_send( struct link *manager, struct work_queue_resource *r, const char *name, time_t stoptime )
 {
 	work_queue_resource_debug(r, name);
-	link_printf(manager, stoptime, "resource %s %"PRId64" %"PRId64" %"PRId64"\n", name, r->total, r->smallest, r->largest );
+	link_putfstring(manager, "resource %s %"PRId64" %"PRId64" %"PRId64"\n", stoptime, name, r->total, r->smallest, r->largest );
 }
 
 void work_queue_resources_send( struct link *manager, struct work_queue_resources *r, time_t stoptime )
@@ -86,19 +86,7 @@ void work_queue_resources_send( struct link *manager, struct work_queue_resource
 	work_queue_resource_send(manager, &r->cores,   "cores",  stoptime);
 
 	/* send the tag last, the manager knows when the resource update is complete */
-	link_printf(manager, stoptime, "resource tag %"PRId64"\n", r->tag);
-}
-
-void work_queue_coprocess_resources_send( struct link *manager, struct work_queue_resources *r, time_t stoptime ) 
-{
-	if (!r) {
-		return;
-	}
-	debug(D_WQ, "Sending coprocess resource description to manager:");
-	work_queue_resource_send(manager, &r->disk,    "coprocess_disk",   stoptime);
-	work_queue_resource_send(manager, &r->memory,  "coprocess_memory", stoptime);
-	work_queue_resource_send(manager, &r->gpus,    "coprocess_gpus",   stoptime);
-	work_queue_resource_send(manager, &r->cores,   "coprocess_cores",  stoptime);
+	link_putfstring(manager, "resource tag %"PRId64"\n", stoptime, r->tag);
 }
 
 void work_queue_resources_debug( struct work_queue_resources *r )
