@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 The University of Notre Dame
+Copyright (C) 2010- The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -50,7 +50,6 @@ int catalog_size = CATALOG_SIZE;
 static struct jx **global_catalog = NULL; //pointer to an array of jx pointers
 struct jx *jexpr = NULL;
 static int columns = 80;
-int manual_ssl_option = 0;
 
 /* negative columns mean a minimum of abs(value), but the column may expand if
  * columns available. */
@@ -112,8 +111,8 @@ static struct jx_table manager_resource_headers[] = {
 {"cores_inuse",		"INUSE", 	    JX_TABLE_MODE_PLAIN, JX_TABLE_ALIGN_RIGHT, 6},
 {"memory_total",	"MEM(GB)",     JX_TABLE_MODE_GIGABYTES, JX_TABLE_ALIGN_RIGHT, 8},
 {"memory_inuse",	"INUSE", 	JX_TABLE_MODE_GIGABYTES, JX_TABLE_ALIGN_RIGHT, 8},
-{"gpus_total",  	"GPUS",  	JX_TABLE_MODE_PLAIN, JX_TABLE_ALIGN_RIGHT, 9},
-{"gpus_inuse",		"INUSE", 	JX_TABLE_MODE_PLAIN, JX_TABLE_ALIGN_RIGHT, 9},
+{"disk_total",  	"DISK(GB)",  	JX_TABLE_MODE_GIGABYTES, JX_TABLE_ALIGN_RIGHT, 9},
+{"disk_inuse",		"INUSE", 	JX_TABLE_MODE_GIGABYTES, JX_TABLE_ALIGN_RIGHT, 9},
 {NULL,NULL,0,0,0}
 };
 
@@ -148,15 +147,13 @@ static void show_help(const char *progname)
 	fprintf(stdout, " %-30s Send debugging to this file. (can also be :stderr,\n", "-o,--debug-file=<file>");
 	fprintf(stdout, " %-30s or :stdout)\n", "");
 	fprintf(stdout, " %-30s Rotate debug file once it reaches this size.\n", "-O,--debug-rotate-max=<bytes>");
-	fprintf(stdout, " %-30s Use SSL when directly connecting to a manager.", "--ssl");
 	fprintf(stdout, " %-30s Show work_queue_status version.\n", "-v,--version");
 	fprintf(stdout, " %-30s This message.\n", "-h,--help");
 }
 
 enum {
 	LONG_OPT_WHERE=1000,
-	LONG_OPT_CAPACITY,
-	LONG_OPT_USE_SSL
+	LONG_OPT_CAPACITY
 };
 
 static void work_queue_status_parse_command_line_arguments(int argc, char *argv[], const char **manager_host, int *manager_port, const char **project_name)
@@ -178,7 +175,6 @@ static void work_queue_status_parse_command_line_arguments(int argc, char *argv[
 		{"version", no_argument, 0, 'v'},
 		{"help", no_argument, 0, 'h'},
 		{"where", required_argument, 0, LONG_OPT_WHERE},
-		{"ssl", no_argument, 0, LONG_OPT_USE_SSL},
 		{0,0,0,0}};
 
 	signed int c;
@@ -253,9 +249,6 @@ static void work_queue_status_parse_command_line_arguments(int argc, char *argv[
 				exit(1);
 			}
 			break;
-		case LONG_OPT_USE_SSL:
-			manual_ssl_option=1;
-			break;
 		default:
 			show_help(argv[0]);
 			exit(EXIT_FAILURE);
@@ -491,17 +484,12 @@ int do_direct_query( const char *manager_host, int manager_port, time_t stoptime
 		return 1;
 	}
 
-	if(manual_ssl_option && link_ssl_wrap_connect(l, manager_host) < 1) {
-		fprintf(stderr,"could not setup ssl connection.\n");
-		return 1;
-	}
-
-	link_printf(l,stoptime,"%s_status\n",query_string);
+	link_putfstring(l,"%s_status\n",stoptime,query_string);
 
 	struct jx *jarray = jx_parse_link(l,stoptime);
 
 	if(!jarray || jarray->type != JX_ARRAY) {
-		fprintf(stderr,"couldn't read from %s port %d: %s\n",manager_host,manager_port,strerror(errno));
+		fprintf(stderr,"couldn't read from %s port %d: %s",manager_host,manager_port,strerror(errno));
 		return 1;
 	}
 
