@@ -3,26 +3,16 @@ set -e
 
 . ../../dttools/test/test_runner_common.sh
 
-import_config_val CCTOOLS_PYTHON_TEST_EXEC
-import_config_val CCTOOLS_PYTHON_TEST_DIR
-import_config_val CCTOOLS_OPSYS
-
-export PATH=$(pwd)/../src:$(pwd)/../../batch_job/src:$PATH
-export PYTHONPATH=$(pwd)/../../test_support/python_modules/${CCTOOLS_PYTHON_TEST_DIR}:$PYTHONPATH
+python=${CCTOOLS_PYTHON_TEST_EXEC}
+python_dir=${CCTOOLS_PYTHON_TEST_DIR}
 
 STATUS_FILE=wq.status
 PORT_FILE=wq.port
 
+
 check_needed()
 {
-	[ -n "${CCTOOLS_PYTHON_TEST_EXEC}" ] || return 1
-
-	if [ "${CCTOOLS_OPSYS}" = DARWIN ]
-	then
-		return 1
-	fi
-
-	return 0
+	[ -n "${python}" ] || return 1
 }
 
 prepare()
@@ -35,14 +25,24 @@ prepare()
 
 run()
 {
-	# worker resources (used by worker in factory in wq_alloc_test.py):
+	# worker resources (used by run_local_worker):
 	cores=4
-	memory=2000
-	disk=2000
+	memory=200
+	disk=200
 	gpus=8
 
+	echo $(pwd) ${python}
+
 	# send makeflow to the background, saving its exit status.
-	${CCTOOLS_PYTHON_TEST_EXEC} wq_alloc_test.py $PORT_FILE $cores $memory $disk $gpus; echo $? > $STATUS_FILE
+	(PYTHONPATH=$(pwd)/../src/bindings/${python_dir} ${python} wq_alloc_test.py $PORT_FILE $cores $memory $disk $gpus; echo $? > $STATUS_FILE) &
+
+	# wait at most 5 seconds for makeflow to find a port.
+	wait_for_file_creation $PORT_FILE 2
+
+	run_local_worker $PORT_FILE worker.log
+
+	# wait for wq script to exit.
+	wait_for_file_creation $STATUS_FILE 5
 
 	# retrieve wq script exit status
 	status=$(cat $STATUS_FILE)
