@@ -3,10 +3,8 @@ set -e
 
 . ../../dttools/test/test_runner_common.sh
 
-import_config_val CCTOOLS_PYTHON_TEST_EXEC
-import_config_val CCTOOLS_PYTHON_TEST_DIR
-
-export PYTHONPATH=$(pwd)/../../test_support/python_modules/${CCTOOLS_PYTHON_TEST_DIR}:$PYTHONPATH
+python=${CCTOOLS_PYTHON_TEST_EXEC}
+python_dir=${CCTOOLS_PYTHON_TEST_DIR}
 
 STATUS_FILE=wq.status
 PORT_FILE=wq.port
@@ -14,7 +12,7 @@ PORT_FILE=wq.port
 
 check_needed()
 {
-	[ -n "${CCTOOLS_PYTHON_TEST_EXEC}" ] || return 1
+	[ -n "${python}" ] || return 1
 }
 
 prepare()
@@ -38,15 +36,15 @@ prepare()
 run()
 {
 	# send makeflow to the background, saving its exit status.
-	(${CCTOOLS_PYTHON_TEST_EXEC} wq_test.py $PORT_FILE; echo $? > $STATUS_FILE) &
+	(PYTHONPATH=$(pwd)/../src/bindings/${python_dir} ${python} wq_test.py $PORT_FILE; echo $? > $STATUS_FILE) &
 
-	# wait at most 15 seconds for wq to find a port.
-	wait_for_file_creation $PORT_FILE 15
+	# wait at most 5 seconds for makeflow to find a port.
+	wait_for_file_creation $PORT_FILE 2
 
-	run_wq_worker $PORT_FILE worker.log
+	run_local_worker $PORT_FILE worker.log
 
-	# wait for wq to exit.
-	wait_for_file_creation $STATUS_FILE 15
+	# wait for makeflow to exit.
+	wait_for_file_creation $STATUS_FILE 5
 
 	# retrieve makeflow exit status
 	status=$(cat $STATUS_FILE)
